<?php
/**
* 2007-2024 PrestaShop
*
* NOTICE OF LICENSE
*
* This source file is subject to the Academic Free License (AFL 3.0)
* that is bundled with this package in the file LICENSE.txt.
* It is also available through the world-wide-web at this URL:
* http://opensource.org/licenses/afl-3.0.php
* If you did not receive a copy of the license and are unable to
* obtain it through the world-wide-web, please send an email
* to license@prestashop.com so we can send you a copy immediately.
*
* DISCLAIMER
*
* Do not edit or add to this file if you wish to upgrade PrestaShop to newer
* versions in the future. If you wish to customize PrestaShop for your
* needs please refer to http://www.prestashop.com for more information.
*
*  @author    PrestaShop SA <contact@prestashop.com>
*  @copyright 2007-2024 PrestaShop SA
*  @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
*  International Registered Trademark & Property of PrestaShop SA
*/

if (!defined('_PS_VERSION_')) {
    exit;
}

include_once(_PS_MODULE_DIR_).'addifyrequestaquote/classes/AddifyrequestaquoteClass.php';
include_once(_PS_MODULE_DIR_).'addifyrequestaquote/classes/AddifyrequestsallClass.php';
include_once(_PS_MODULE_DIR_).'addifyrequestaquote/classes/AddifycartsallClass.php';
include_once(_PS_MODULE_DIR_).'addifyrequestaquote/classes/AddifyRequestAQuoteCustomFieldsModel.php';
include_once(_PS_MODULE_DIR_).'addifyrequestaquote/classes/AddifyRequestAQuoteCustomFieldsDataModel.php';
include_once(_PS_MODULE_DIR_).'addifyrequestaquote/classes/AddifyQuoteAllMessageClass.php';

class Addifyrequestaquote extends Module
{
    protected $config_form = false;

    public function __construct()
    {
        $this->name = 'addifyrequestaquote';
        $this->tab = 'front_office_features';
        $this->version = '1.4.0';
        $this->author = 'Addify';
        $this->need_instance = 0;
        $this->module_key = 'eb37fca633aaca3aa559dcf33e62579f';
        /**
         * Set $this->bootstrap to true if your module is compliant with bootstrap (PrestaShop 1.6)
         */
        $this->bootstrap = true;
        parent::__construct();
        $this->displayName = $this->l('Addify Request A Quote');
        $this->description = $this->l('Allow customers to inquire about product pricing, enhancing engagement with customizable forms and efficient request management.');
        $this->ps_versions_compliancy = array('min' => '1.6', 'max' => _PS_VERSION_);
    }

    /**
     * Don't forget to create update methods if needed:
     * http://doc.prestashop.com/display/PS16/Enabling+the+Auto-Update
     */
    public function install()
    {
        include(dirname(__FILE__).'/sql/install.php');
        Configuration::updateValue('ADDIFYREQUESTAQUOTE_LIVE_MODE', 1);
        Configuration::updateValue('ADDIFYREQUESTAQUOTE_OFFERED_MODE', 1);
        Configuration::updateValue('ADDIFYREQUESTAQUOTE_SEMAIL', '');
        Configuration::updateValue('ADDIFYREQUESTAQUOTE_TEXTTYPE_ACTIVE', 0);
        Configuration::updateValue('ADDIFYREQUESTAQUOTE_TEXTTYPE_LABLE', '');
        Configuration::updateValue('ADDIFYREQUESTAQUOTE_TEXTTYPE_PLACEHOLDER', '');
        Configuration::updateValue('ADDIFYREQUESTAQUOTE_FILEUPLOAD_ACTIVE', 0);
        Configuration::updateValue('ADDIFYREQUESTAQUOTE_FILEUPLOAD_LABLE', '');
        Configuration::updateValue('ADDIFYREQUESTAQUOTE_MULTICHECK_ACTIVE', 0);
        Configuration::updateValue('ADDIFYREQUESTAQUOTE_MULTICHECK_LABLE', '');
        Configuration::updateValue('ADDIFYREQUESTAQUOTE_MULTICHECK_OPTIONS', '');
        Configuration::updateValue('ADDIFYREQUESTAQUOTE_DROPDOWN_ACTIVE', 0);
        Configuration::updateValue('ADDIFYREQUESTAQUOTE_DROPDOWN_LABLE', '');
        Configuration::updateValue('ADDIFYREQUESTAQUOTE_DROPDOWN_OPTIONS', '');
        Configuration::updateValue('ADDIFYREQUESTAQUOTE_TEXT_COLOR', '#4285f4');
        Configuration::updateValue('ADDIFYREQUESTAQUOTE_TEXT_BG_COLOR', '#515356');
        Configuration::updateValue('ADDIFYREQUESTAQUOTE_MESSAGE', 'Add to Quote');

        return parent::install() &&
            $this->registerHook('displayHeader') &&
            $this->registerHook('displayBackOfficeHeader') && 
            $this->registerHook('displayTop') &&
            $this->registerHook('displayProductPriceBlock') &&
            $this->registerHook('displayCustomerAccount') &&
            $this->registerHook('actionDeleteGDPRCustomer') && 
            $this->registerHook('actionExportGDPRData');
    }

    public function uninstall()
    {
        include(dirname(__FILE__).'/sql/uninstall.php');
        Configuration::deleteByName('ADDIFYREQUESTAQUOTE_TEXTTYPE_ACTIVE');
        Configuration::deleteByName('ADDIFYREQUESTAQUOTE_TEXTTYPE_LABLE');
        Configuration::deleteByName('ADDIFYREQUESTAQUOTE_TEXTTYPE_PLACEHOLDER');
        Configuration::deleteByName('ADDIFYREQUESTAQUOTE_FILEUPLOAD_ACTIVE');
        Configuration::deleteByName('ADDIFYREQUESTAQUOTE_FILEUPLOAD_LABLE');
        Configuration::deleteByName('ADDIFYREQUESTAQUOTE_MULTICHECK_ACTIVE');
        Configuration::deleteByName('ADDIFYREQUESTAQUOTE_MULTICHECK_LABLE');
        Configuration::deleteByName('ADDIFYREQUESTAQUOTE_MULTICHECK_OPTIONS');
        Configuration::deleteByName('ADDIFYREQUESTAQUOTE_DROPDOWN_ACTIVE');
        Configuration::deleteByName('ADDIFYREQUESTAQUOTE_DROPDOWN_LABLE');
        Configuration::deleteByName('ADDIFYREQUESTAQUOTE_DROPDOWN_OPTIONS');
        Configuration::deleteByName('ADDIFYREQUESTAQUOTE_COMPANYNAME_ACTIVE');
        Configuration::deleteByName('ADDIFYREQUESTAQUOTE_COMPANYNAME_LABLE');
        Configuration::deleteByName('ADDIFYREQUESTAQUOTE_COMPANYNAME_MANDATORY');
        Configuration::deleteByName('ADDIFYREQUESTAQUOTE_WEBSITE_ACTIVE');
        Configuration::deleteByName('ADDIFYREQUESTAQUOTE_WEBSITE_LABLE');
        Configuration::deleteByName('ADDIFYREQUESTAQUOTE_WEBSITE_MANDATORY');
        Configuration::deleteByName('ADDIFYREQUESTAQUOTE_PHONE_ACTIVE');
        Configuration::deleteByName('ADDIFYREQUESTAQUOTE_PHONE_LABLE');
        Configuration::deleteByName('ADDIFYREQUESTAQUOTE_PHONE_MANDATORY');
        Configuration::deleteByName('ADDIFYREQUESTAQUOTE_VATNUMBER_ACTIVE');
        Configuration::deleteByName('ADDIFYREQUESTAQUOTE_VATNUMBER_LABLE');
        Configuration::deleteByName('ADDIFYREQUESTAQUOTE_VATNUMBER_MANDATORY');
        Configuration::deleteByName('ADDIFYREQUESTAQUOTE_FILEUPLOAD_MANDATORY');
        Configuration::deleteByName('ADDIFYREQUESTAQUOTE_TEXTTYPE_MANDATORY');
        Configuration::deleteByName('ADDIFYREQUESTAQUOTE_DROPDOWN_MANDATORY');
        Configuration::deleteByName('ADDIFYREQUESTAQUOTE_MULTISELECT_MANDATORY');
        Configuration::deleteByName('ADDIFYREQUESTAQUOTE_LIVE_MODE');
        Configuration::deleteByName('ADDIFYREQUESTAQUOTE_OFFERED_MODE');
        Configuration::deleteByName('ADDIFYREQUESTAQUOTE_SEMAIL');
        Configuration::deleteByName('ADDIFYREQUESTAQUOTE_CATALOGMODE_ENABLE');
        Configuration::deleteByName('ADDIFYREQUESTAQUOTE_HIDEPRICE');
        Configuration::deleteByName('ADDIFYREQUESTAQUOTE_HIDECART');
        Configuration::deleteByName('ADDIFYREQUESTAQUOTE_MESSAGE');
        Configuration::deleteByName('ADDIFYREQUESTAQUOTE_TEXT_COLOR');
        Configuration::deleteByName('ADDIFYREQUESTAQUOTE_TEXT_BG_COLOR');
        Configuration::deleteByName('ADDIFYREQUESTAQUOTE_HIDEQUOTE');
        Configuration::deleteByName('ADDIFYREQUESTAQUOTE_SEMAIL_ENABLE');
        Configuration::deleteByName('ADDIFYREQUESTAQUOTE_ENABLE_MESSAGE_NOTIFY');
        Configuration::deleteByName('ADDIFYREQUESTAQUOTE_ENABLE_OUTOFSTOCK');

        return parent::uninstall() &&
            $this->unregisterHook('displayHeader') &&
            $this->unregisterHook('displayBackOfficeHeader') && 
            $this->unregisterHook('displayTop') &&
            $this->unregisterHook('displayProductPriceBlock') &&
            $this->unregisterHook('displayCustomerAccount') && 
            $this->unregisterHook('actionDeleteGDPRCustomer') && 
            $this->unregisterHook('actionExportGDPRData');
    }

    /**
     * Load the configuration form
     */
    public function getContent()
    {
        $active_tab = Tools::getValue('active_tab');
        if (!$active_tab) {
           $active_tab = 1;
        }

        $adminToken = Tools::getAdminTokenLite('AdminModules');
        $formurl = $this->context->link->getAdminLink('AdminModules', true) . '&configure=' . $this->name . '&module_name=' . $this->name;

        $this->context->smarty->assign(array(
            'renderconfigForm' => $this->renderconfigForm(), // General settings Tab 1
            'renderList' => $this->renderList(), // Rules Tab 3
            'renderRequestList' => $this->renderRequestList(), // Quotations Tab 2
            'renderPredefinedConfigForm' => $this->renderPredefinedConfigForm(), // Predefined Fields Tab 4
            'renderFieldsList' => $this->renderFieldsList(), // Custom Fields Tab 5 
            'renderQuoteMessageList' => $this->renderQuoteMessageList(), // Custom Fields Tab 6 
            'active_tab' => $active_tab, 
        ));

        $this->context->smarty->assign('module_dir', $this->_path);


        if(Tools::isSubmit('submitaddifyrfqMessage')) {

            $dt = date("Y-m-d h:i:s");

            $current_date_time = date("Y-m-d h:i:sa");

            $admin_thread = 1;

            $id_quotemessage = Tools::getValue('id_quotemessage');

            $quote_id = Tools::getValue('quote_id');

            $rfq_message = Tools::getValue('rfq_message');

            $requestaquote = new AddifyrequestsallClass((int)$quote_id);
            $customer_id = (int)$requestaquote->id_customer;
        
            $final_msg = $admin_thread."|>".$current_date_time.'|>'.$rfq_message;

            $Customer = new Customer($customer_id);
            $Customer_name = $Customer->firstname.$Customer->lastname;
            $Customer_email = $Customer->email; 

            $quotemessages = AddifyQuoteAllMessageClass::getDataByQuote((int)$quote_id);

            if ($quotemessages) {
                $id_quotemessage = $quotemessages[0]['id_quotemessage'];
                $db_quotemessage = $quotemessages[0]['message'];

                $exp = explode(",", $db_quotemessage);

                $exp[] = $final_msg;

                $final_msg  = implode(',', $exp);
            }

            $adminemail = Configuration::get('PS_SHOP_EMAIL');

            $admin_name = "Shop Admin";

            $this->sendMailMessage($Customer_email,$admin_name,Tools::getValue('rfq_message'), $quote_id);

            if ($id_quotemessage) {
                $AddifyQuoteAllMessageClass= new AddifyQuoteAllMessageClass((int)$id_quotemessage);
                $AddifyQuoteAllMessageClass->date_update = $dt;

                $AddifyQuoteAllMessageClass->quote_id = $quote_id;
                $AddifyQuoteAllMessageClass->id_customer = $customer_id;
                $AddifyQuoteAllMessageClass->customer_name = $Customer_name;
                $AddifyQuoteAllMessageClass->email = $Customer_email;
                $AddifyQuoteAllMessageClass->message = $final_msg;
                
                $AddifyQuoteAllMessageClass->save();

            }else{
                $AddifyQuoteAllMessageClass = new AddifyQuoteAllMessageClass();
                $AddifyQuoteAllMessageClass->date_add = $dt;

                $AddifyQuoteAllMessageClass->quote_id = $quote_id;
                $AddifyQuoteAllMessageClass->id_customer = $customer_id;
                $AddifyQuoteAllMessageClass->customer_name = $Customer_name;
                $AddifyQuoteAllMessageClass->email = $Customer_email;
                $AddifyQuoteAllMessageClass->message = $final_msg;
                
                $AddifyQuoteAllMessageClass->save();
            }

            Tools::redirectAdmin($this->context->link->getAdminLink('AdminModules', true) . '&quotemessagealert=1&configure=' . $this->name . '&tab_module=' . $this->tab . '&module_name=' . $this->name.'&quotemessageaddifyrequestaquote'.'&viewaddifyrfqallmessages=&quote_id='.$quote_id);
        }


        if(Tools::isSubmit('viewaddifyrfqallmessages')) {

            $backurl = $this->context->link->getAdminLink('AdminModules', true) . '&configure=' . $this->name . '&tab_module=' . $this->tab . '&module_name=' . $this->name.'&quotemessageaddifyrequestaquote';

            $id_quotemessage = Tools::getValue('id_quotemessage'); 

            $id_quotation = Tools::getValue('quote_id'); 

        
            if ($id_quotemessage) {
                $quotemessages = AddifyQuoteAllMessageClass::getDataByIDMessage((int)$id_quotemessage);

                $id_quotation = $quotemessages[0]['quote_id'];

            }else{

                $quotemessages = AddifyQuoteAllMessageClass::getDataByQuote((int)$id_quotation);
            }

            $quotemessagealert = 0;

            $quotemessagealert = Tools::getValue('quotemessagealert');

            if ($quotemessagealert) {
               $quotemessagealert = 1;
            }


            $formurl_message = $this->context->link->getAdminLink('AdminModules', true) . '&configure=' . $this->name . '&module_name=' . $this->name.'&quotemessageaddifyrequestaquote'. '&quote_id='.$id_quotation;

            $quotation_url = $this->context->link->getAdminLink('AdminModules', true) . '&configure=' . $this->name . '&module_name=' . $this->name.'&quotationsaddifyrequestaquote'.'&updateaddifyrequestsall=&id_addifyrequestaquote='.$id_quotation;

            $this->context->smarty->assign(array(

                'backurl' => $backurl,
                'quotation_url' => $quotation_url,
                'quotemessages' => $quotemessages,
                'quotemessagealert' => $quotemessagealert,
                'formurl' => $formurl_message
            ));


            $output = $this->context->smarty->fetch($this->local_path.'views/templates/admin/allmessages.tpl');
            
            $active_tab = 6;
            $this->context->smarty->assign(array(
                'renderQuoteMessageList' => $output,  
                'active_tab' => $active_tab, 
            ));

            $configure = $this->context->smarty->fetch($this->local_path.'views/templates/admin/configure.tpl');
            return $configure;
        }

        if(Tools::isSubmit('Submitrequestsall')) { // admin => accept or reject or pending the code
            $id_addifyrequestaquote = Tools::getValue('id_addifyrequestaquote'); 
            $requestaquote = new AddifyrequestsallClass((int)$id_addifyrequestaquote);
            $requestaquote->status = Tools::getValue('status');
            $requestaquote->id_product = Tools::getValue('allpids');
            $requestaquote->id_product_attribute = Tools::getValue('allpattr');
            $requestaquote->admin_price = Tools::getValue('admin_price');
            $requestaquote->product_info = Tools::getValue('allpinfo');
            $requestaquote->product_image = Tools::getValue('allpimages');
            $requestaquote->product_name = Tools::getValue('allpname');
            $requestaquote->product_sku = Tools::getValue('allpsku');
            $requestaquote->offered_price = Tools::getValue('offered_price');
            $requestaquote->quantity = Tools::getValue('quantity');
            $requestaquote->name = Tools::getValue('name');
            $requestaquote->email = Tools::getValue('email');
            $requestaquote->description = Tools::getValue('description');
            $requestaquote->cartlink = Tools::getValue('cartlink');

            if(Tools::getValue('addifyraq_enable') == 1) {
                $requestaquote->sendlinkflag = 1;
                if(Tools::getValue('cartlink') != ''){

                    $allpimages=explode(',',Tools::getValue('allpimages'));
                    $allpname=explode(',',Tools::getValue('allpname'));
                    $allpsku=explode(',',Tools::getValue('allpsku'));
                    $allpinfo=explode(',',Tools::getValue('allpinfo'));
                    $quantity=explode(',',Tools::getValue('quantity'));
                    $offered_price=explode(',',Tools::getValue('offered_price'));
                    $counnt=(int)count($allpname);
                    $curr=Currency::getDefaultCurrency()->sign;

                    $this->context->smarty->assign('counnt', (int)($counnt-1));
                    $this->context->smarty->assign('allpimages', $allpimages);
                    $this->context->smarty->assign('allpname', $allpname);
                    $this->context->smarty->assign('allpsku', $allpsku);
                    $this->context->smarty->assign('allpinfo', $allpinfo);
                    $this->context->smarty->assign('quantity', $quantity);
                    $this->context->smarty->assign('offered_price', $offered_price);
                    $this->context->smarty->assign('curr', $curr);
                    $this->context->smarty->assign('aadifyraq_offered_mode', Configuration::get('ADDIFYREQUESTAQUOTE_OFFERED_MODE'));


                    $quote_title_display = $this->l('Quote Details');
                    $requested_quote_prods = $this->l('Requested quote products');
                    $name_label = $this->l('Name');
                    $email_label = $this->l('Email');
                    $des_label = $this->l('Description');

                    $texttype = $requestaquote->texttype;
                    $dropdown = $requestaquote->dropdown;
                    $file = $requestaquote->file;
                    $multiselect = $requestaquote->multiselect;
                    $company = $requestaquote->company;
                    $website = $requestaquote->website;
                    $phone = $requestaquote->phone;
                    $vatnumber = $requestaquote->vatnumber;


                    if (trim($file ?? '') == ':') {
                        $file = '';
                    }

                    if (trim($dropdown ?? '') == ':') {
                        $dropdown = '';
                    }

                    if (trim($texttype ?? '') == ':') {
                        $texttype = '';
                    }

                    if (trim($multiselect ?? '') == ':') {
                        $multiselect = '';
                    }

                    if (trim($company ?? '') == ':') {
                        $company = '';
                    }

                    if (trim($website ?? '') == ':') {
                        $website = '';
                    }

                    if (trim($phone ?? '') == ':') {
                        $phone = '';
                    }

                    if (trim($vatnumber ?? '') === ':') {
                        $vatnumber = '';
                    }

                    if (!empty($file)) {
                        $File_split = explode(":", $file, 2);

                        if ($File_split) {
                            $file_Heading = isset($File_split[0]) ? $File_split[0] : ''; // First part of the split
                            $file_source = isset($File_split[1]) ? $File_split[1] : '';   // Second part of the split

                            if (!empty($file_source)) {
                                $file_Image = _PS_BASE_URL_.__PS_BASE_URI__.'modules/addifyrequestaquote/views/img/'.trim($file_source);
                            } else {
                                $file_Image = ''; // Assign empty string if $file_source is empty
                            }
                        } else {
                            $file_Heading = '';
                            $file_Image = '';
                            $file_source = '';
                        }
                    } else {
                        $file_Heading = '';
                        $file_Image = '';
                        $file_source = '';
                    }

                    $customfieldsdata = AddifyRequestAQuoteCustomFieldsDataModel::getData((int)$id_addifyrequestaquote);

                    $this->context->smarty->assign(array(
                        'text_active' => Configuration::get('ADDIFYREQUESTAQUOTE_TEXTTYPE_ACTIVE'),
                        'dropdown_active' => Configuration::get('ADDIFYREQUESTAQUOTE_FILEUPLOAD_ACTIVE'),
                        'fileuplod_active' => Configuration::get('ADDIFYREQUESTAQUOTE_MULTICHECK_ACTIVE'),
                        'multicheck_active' => Configuration::get('ADDIFYREQUESTAQUOTE_DROPDOWN_ACTIVE'),
                        'company_active' => Configuration::get('ADDIFYREQUESTAQUOTE_COMPANYNAME_ACTIVE'),
                        'website_active' => Configuration::get('ADDIFYREQUESTAQUOTE_WEBSITE_ACTIVE'),
                        'phone_active' => Configuration::get('ADDIFYREQUESTAQUOTE_PHONE_ACTIVE'),
                        'vatnumber_active' => Configuration::get('ADDIFYREQUESTAQUOTE_VATNUMBER_ACTIVE'),

                        'text_label' => Configuration::get('ADDIFYREQUESTAQUOTE_TEXTTYPE_LABLE'),
                        'dropdown_label' => Configuration::get('ADDIFYREQUESTAQUOTE_DROPDOWN_LABLE'),
                        'fileuplod_label' => Configuration::get('ADDIFYREQUESTAQUOTE_FILEUPLOAD_LABLE'),
                        'multicheck_label' => Configuration::get('ADDIFYREQUESTAQUOTE_MULTICHECK_LABLE'),
                        'company_label' => Configuration::get('ADDIFYREQUESTAQUOTE_COMPANYNAME_LABLE'),
                        'website_label' => Configuration::get('ADDIFYREQUESTAQUOTE_WEBSITE_LABLE'),
                        'phone_label' => Configuration::get('ADDIFYREQUESTAQUOTE_PHONE_LABLE'),
                        'vatnumber_label' => Configuration::get('ADDIFYREQUESTAQUOTE_VATNUMBER_LABLE'),
                        'email' => Tools::getValue('email'),
                        'name' => Tools::getValue('name'),
                        'dateTime' => date ('Y-m-d H:i:s'),
                        'name_label' => $name_label,
                        'email_label' => $email_label,
                        'des' => Tools::getValue('description'),
                        'des_label' => $des_label,

                        'dropdown'=> explode(":", $dropdown ?? '', 2),
                        'texttype'=> explode(":", $texttype ?? '', 2),
                        'multiselect'=> explode(":", $multiselect ?? '', 2),
                        'company' => explode(":", $company ?? '', 2), 
                        'website' => explode(":", $website ?? '', 2), 
                        'phone' => explode(":", $phone ?? '', 2),
                        'vatnumber' => explode(":", $vatnumber ?? '', 2),
                        'file' => $file_Image,

                        'quote_title_display' => $quote_title_display,
                        'requested_quote_prods' => $requested_quote_prods,
                        'customfieldsdata' => $customfieldsdata,
                        'link' => Tools::getValue('cartlink'),

                    ));

                    $table = $this->context->smarty->fetch(_PS_MODULE_DIR_.'addifyrequestaquote/views/templates/front/cartlinkemail.tpl');

                    $this->sendMail(Tools::getValue('email'),Tools::getValue('name'),Tools::getValue('cartlink'), $table);
                }
            }

            $requestaquote->adminnote = Tools::getValue('adminnote');

            $allitems = explode(',',Tools::getValue('allpids'));
            $itemscount=count($allitems);
            for($i=0;$i<$itemscount;$i++) {
                if($i==0) {
                    $allitems=Tools::getValue('adminprice'.$i);
                } else {
                    $allitems=$allitems.','.Tools::getValue('adminprice'.$i);
                }     
            }

            $requestaquote->save();
            Tools::redirectAdmin($this->context->link->getAdminLink('AdminModules', true) . '&conf=4&configure=' . $this->name . '&tab_module=' . $this->tab . '&module_name=' . $this->name.'&quotationsaddifyrequestaquote');
        }


        if(Tools::isSubmit('updateaddifyrequestsall')) {
            $id_addifyrequestaquote = Tools::getValue('id_addifyrequestaquote'); 
            $requestaquote = new AddifyrequestsallClass((int)$id_addifyrequestaquote);
            $status = $requestaquote->status;
            $allid_product = $requestaquote->id_product;
            $allid_productarr = explode(',', $requestaquote->id_product);
            $allpattr = $requestaquote->id_product_attribute;
            $allpattrarr = explode(',',$requestaquote->id_product_attribute);
            $allpinfo = $requestaquote->product_info;
            $allpinfoarr = explode(',',$requestaquote->product_info);
            $allpimages = $requestaquote->product_image;
            $allpimagesarr = explode(',',$requestaquote->product_image);
            $allpname = $requestaquote->product_name;
            $allpnamearr = explode(',',$requestaquote->product_name);
            $allpsku = $requestaquote->product_sku;
            $allpskuarr = explode(',',$requestaquote->product_sku);
            $offered_price = $requestaquote->offered_price ;
            $offered_pricearr = explode(',',$requestaquote->offered_price);
            $original_price = $requestaquote->original_price ;
            $original_pricearr = explode(',',$requestaquote->original_price) ;
            $quantity = $requestaquote->quantity ;
            $quantityarr = explode(',',$requestaquote->quantity) ;
            $name = $requestaquote->name ;
            $email = $requestaquote->email ;
            $description = $requestaquote->description ;
            $adminnote = $requestaquote->adminnote;
            $file = $requestaquote->file ;
            $dropdown = $requestaquote->dropdown ;
            $texttype = $requestaquote->texttype ;
            $discountProductHere = '';
            $discountProductAdmin = $requestaquote->quote_product_discount;
            if ($discountProductAdmin) {
                $discountProductHere = explode(',',$discountProductAdmin);
            }

            $quote_name = $requestaquote->quote_name;
            if (!$discountProductHere) { // admin disocunt quote
                $quote_name = $this->l("Quote From Customer");
            }

            $company = $requestaquote->company ;
            $website = $requestaquote->website ;
            $phone = $requestaquote->phone ;
            $vatnumber = $requestaquote->vatnumber ;
            $multiselect = $requestaquote->multiselect ;
            $admin_price = $requestaquote->admin_price ;
            $sendlinkflag = $requestaquote->sendlinkflag;
            $cartlink = $requestaquote->cartlink;
            $cartexpire = $requestaquote->cartexpire;
            if ($cartexpire != '') {
                $cartexpire = $this->l(" ---- Expiry Date : ")  . $cartexpire;
            }

            $cartkey = $requestaquote->cartkey;
            $admin_pricearr = explode(',',$requestaquote->admin_price) ;
            $number_of_products = count($allid_productarr);
            $customer_id = $requestaquote->id_customer;
            if ($customer_id) {
                $Customer = new Customer($customer_id);
                $Customer_name = $Customer->firstname.$Customer->lastname;
                $Customer_email = $Customer->email; 
            }
            $pro_tax = [];
            $pro_DISCOUNT = [];
            $additional_shipping_cost = [];
            if (empty($allid_productarr[0])) {
                $pro_DISCOUNT = $discountProductHere;
            }

            foreach ($allid_productarr as $key => $id_product) {
                if ($id_product) {
                    $product = new Product($id_product);
                    $additional_shipping_cost[] = $product->additional_shipping_cost;
                    $id_product_attribute = $allpattrarr[$key];
                    $PRICE_WITH_T = Product::getPriceStatic($id_product, true, $id_product_attribute);
                    $PRICE_WITHOUT_T = Product::getPriceStatic($id_product ,false, $id_product_attribute);
                    $PRICE_WITH_D = Product::getPriceStatic($id_product ,true, $id_product_attribute, 6, null, false, true);
                    $PRICE_WITHOUT_D = Product::getPriceStatic($id_product ,true, $id_product_attribute, 6, null, false, false);
                    $pro_tax[] = $PRICE_WITH_T - $PRICE_WITHOUT_T;
                    $pro_DISCOUNT[] = $PRICE_WITHOUT_D - $PRICE_WITH_D;
                }
            }

            $today_date = date("Y-m-d");

            $addifyraq_ajax_link = $this->context->link->getAdminLink('AdminAddifyrequestaquoteCartlink',true);

            $backurl = $this->context->link->getAdminLink('AdminModules', true) . '&configure=' . $this->name . '&tab_module=' . $this->tab . '&module_name=' . $this->name.'&quotationsaddifyrequestaquote';

            $customfieldsdata = AddifyRequestAQuoteCustomFieldsDataModel::getData($id_addifyrequestaquote);

            if (trim($file ?? '') == ':') {
                $file = '';
            }

            if (trim($dropdown ?? '') == ':') {
                $dropdown = '';
            }

            if (trim($texttype ?? '') == ':') {
                $texttype = '';
            }

            if (trim($multiselect ?? '') == ':') {
                $multiselect = '';
            }

            if (trim($company ?? '') == ':') {
                $company = '';
            }

            if (trim($website ?? '') == ':') {
                $website = '';
            }

            if (trim($phone ?? '') == ':') {
                $phone = '';
            }

            if (trim($vatnumber ?? '') === ':') {
                $vatnumber = '';
            }

            if (!empty($file)) {
                $File_split = explode(":", $file, 2);

                if ($File_split) {
                    $file_Heading = isset($File_split[0]) ? $File_split[0] : ''; // First part of the split
                    $file_source = isset($File_split[1]) ? $File_split[1] : '';   // Second part of the split

                    if (!empty($file_source)) {
                        $file_Image = _PS_BASE_URL_.'/'.__PS_BASE_URI__.'modules/addifyrequestaquote/views/img/'.trim($file_source);
                    } else {
                        $file_Image = ''; // Assign empty string if $file_source is empty
                    }
                } else {
                    $file_Heading = '';
                    $file_Image = '';
                    $file_source = '';
                }
            } else {
                $file_Heading = '';
                $file_Image = '';
                $file_source = '';
            }

            $id_customer = (int)$requestaquote->id_customer;

            $messageurl = $this->context->link->getAdminLink('AdminModules', true) . '&configure=' . $this->name . '&module_name=' . $this->name.'&quote_id='.$id_addifyrequestaquote.'&viewaddifyrfqallmessages';
            
            $this->context->smarty->assign(array(

                'id_addifyrequestaquote' => $id_addifyrequestaquote,

                'status' => $status,

                'allid_product' => $allid_product,

                'allid_productarr' => $allid_productarr,

                'allpattr' => $allpattr,

                'allpattrarr' => $allpattrarr,

                'allpinfo' => $allpinfo,

                'allpinfoarr' => $allpinfoarr,

                'allpimages' => $allpimages,

                'allpimagesarr' => $allpimagesarr,

                'allpname' => $allpname,

                'allpnamearr' => $allpnamearr,

                'allpsku' => $allpsku,

                'allpskuarr' => $allpskuarr,

                'offered_price' => $offered_price,

                'offered_pricearr' => $offered_pricearr,

                'original_price' => $original_price,

                'original_pricearr' => $original_pricearr,

                'quantity' => $quantity,
                'quantityarr' => $quantityarr,
                'admin_price' => $admin_price,
                'admin_pricearr' => $admin_pricearr,
                'name' => $name,
                'email' => $email,
                'description' => $description,
                'adminnote' => $adminnote,
                'file_Heading' => $file_Heading,
                'file_Image' => $file_Image,
                'file_source' => $file_source,
                'dropdown'=> explode(":", $dropdown ?? '', 2),
                'texttype'=> explode(":", $texttype ?? '', 2),
                'multiselect'=> explode(":", $multiselect ?? '', 2),
                'company' => explode(":", $company ?? '', 2), 
                'website' => explode(":", $website ?? '', 2), 
                'phone' => explode(":", $phone ?? '', 2),
                'vatnumber' => explode(":", $vatnumber ?? '', 2),
                'Customer_name' => $Customer_name ?? '',
                'Customer_email' => $Customer_email ?? '',
                'quote_name'=> $quote_name ?? '' ,
                'sendlinkflag' => $sendlinkflag,
                'addifyraq_cartlink' => $cartlink,
                'cartexpire' => $cartexpire,
                'cartkey' => $cartkey,
                'today_date' => $today_date,
                'curr' =>  Currency::getDefaultCurrency()->sign,
                'target_dir' => _PS_MODULE_DIR_.'addifyrequestaquote/views/img/',
                'baseUrl' => $this->context->shop->getBaseURL(true),
                'number_of_products' => $number_of_products,
                'backurl' => $backurl,
                'formurl' => $formurl,
                'id_customer' => $id_customer,
                'messageurl' => $messageurl,
                'pro_tax' => $pro_tax,
                'additional_shipping_cost' => $additional_shipping_cost,
                'pro_DISCOUNT' => $pro_DISCOUNT,
                'customfieldsdata' => $customfieldsdata,
                'aadifyraq_offered_mode' => Configuration::get('ADDIFYREQUESTAQUOTE_OFFERED_MODE'),
                'text_active' => Configuration::get('ADDIFYREQUESTAQUOTE_TEXTTYPE_ACTIVE'),
                'dropdown_active' => Configuration::get('ADDIFYREQUESTAQUOTE_FILEUPLOAD_ACTIVE'),
                'fileuplod_active' => Configuration::get('ADDIFYREQUESTAQUOTE_MULTICHECK_ACTIVE'),
                'multicheck_active' => Configuration::get('ADDIFYREQUESTAQUOTE_DROPDOWN_ACTIVE'),
                'company_active' => Configuration::get('ADDIFYREQUESTAQUOTE_COMPANYNAME_ACTIVE'),
                'website_active' => Configuration::get('ADDIFYREQUESTAQUOTE_WEBSITE_ACTIVE'),
                'phone_active' => Configuration::get('ADDIFYREQUESTAQUOTE_PHONE_ACTIVE'),
                'vatnumber_active' => Configuration::get('ADDIFYREQUESTAQUOTE_VATNUMBER_ACTIVE'),
                'addifyraq_ajax_link' => $addifyraq_ajax_link
            ));

            $this->context->smarty->assign('module_dir', $this->_path);
            $output = $this->context->smarty->fetch($this->local_path.'views/templates/admin/allrequest.tpl');
            
            $active_tab = 2;
            $this->context->smarty->assign(array(
                'renderRequestList' => $output,  
                'active_tab' => $active_tab, 
            ));

            $configure = $this->context->smarty->fetch($this->local_path.'views/templates/admin/configure.tpl');
            return $configure;
        }

        /**
         * If values have been submitted in the form, process.
         */
        if(Tools::isSubmit('Submitconfig'.$this->name)) {
            $this->processconfigSave(); // general setting Tab 1
        }

        if(Tools::isSubmit('Submitquotation'.$this->name)) {
            $this->processQuotationsSave(); // Qoutation Tab 2
        }

        if(Tools::isSubmit('Submitpredefinedconfig'.$this->name)) {
            $this->processPredefinedConfigSave(); // Predefined Fields Tab 4
        }

        $this->postProcess(); // Rule Tab (3) + Custom Field Tab (5) operation
        
        // Quotations
        if (Tools::isSubmit('addquotation'.$this->name) || Tools::isSubmit('updatequotation'.$this->name)) { 
            $active_tab = 2;
            $this->context->smarty->assign(array(
                'renderRequestList' => $this->renderQuotationForm(),  
                'active_tab' => $active_tab, 
            ));
            $configure = $this->context->smarty->fetch($this->local_path.'views/templates/admin/configure.tpl');
            return $configure;
        }
        
        // Custom Fields
        if (Tools::isSubmit('addcustomfields'.$this->name) || Tools::isSubmit('update'.$this->name.'customfields') || Tools::isSubmit('status'.$this->name.'customfields')) {
            $active_tab = 5;
            $this->context->smarty->assign(array(
                'renderFieldsList' => $this->renderCustomFieldsForm(),  
                'active_tab' => $active_tab, 
            ));
            $configure = $this->context->smarty->fetch($this->local_path.'views/templates/admin/configure.tpl');
            return $configure;
        }
        
        // Rules
        if (Tools::isSubmit('add'.$this->name) || Tools::isSubmit('update'.$this->name)) {
            $active_tab = 3;
            $this->context->smarty->assign(array(
                'renderList' => $this->renderForm(),  
                'active_tab' => $active_tab, 
            ));
            $configure = $this->context->smarty->fetch($this->local_path.'views/templates/admin/configure.tpl');
            return $configure;
        } 

        if (Tools::isSubmit('quotations'.$this->name)) {
            $active_tab = 2;
        }   

        if (Tools::isSubmit('predefined'.$this->name)) {
            $active_tab = 4;
        }   

        if (Tools::isSubmit('customfields'.$this->name)) {
            $active_tab = 5;
        }   

        if (Tools::isSubmit('quotemessage'.$this->name)) {
            $active_tab = 6;
        }   

        if (Tools::isSubmit('rules'.$this->name)) {
            $active_tab = 3;
        }   

        $this->context->smarty->assign(array(
            'active_tab' => $active_tab, 
        ));

        $configure = $this->context->smarty->fetch($this->local_path.'views/templates/admin/configure.tpl');
        return $configure;
        // return $this->renderconfigForm().$this->renderList().$this->renderRequestList();
    }

    protected function renderList()
    {
        $fields_list = array(
            'id_addifyrequestaquote' => array(
                'title' => $this->l('ID'),
                'width' => 120,
                'type' => 'text',
                'search' => false,
                'orderby' => false
            ),
            'title' => array(
                'title' => $this->l('Title'),
                'width' => 140,
                'type' => 'text',
                'search' => false,
                'orderby' => false
            ),
            'priority' => array(
                'title' => $this->l('Priority'),
                'width' => 140,
                'type' => 'text',
                'search' => false,
                'orderby' => false
            ),
            'active' => array(
                'title' => $this->l('Status'),
                'width' => 140,
                'active' => 'status',
                'type' => 'bool',
                'search' => false,
                'orderby' => false
            ),
            'date_add' => array(
                'title' => $this->l('Added Date'),
                'width' => 140,
                'type' => 'datetime',
                'search' => false,
                'orderby' => false
            ),
            'date_upd' => array(
                'title' => $this->l('Update Date'),
                'width' => 140,
                'type' => 'datetime',
                'search' => false,
                'orderby' => false
            ),
        );

        // multishop feature
        if (Shop::isFeatureActive()) {
            $this->fields_list['id_shop'] = array(
                'title' => $this->l('ID Shop'),
                'align' => 'center',
                'width' => 25,
                'type' => 'int'
            );
        }

        $helper = new HelperList();
        $helper->shopLinkType = '';
        $helper->simple_header = false;
        $helper->identifier = 'id_addifyrequestaquote';
        $helper->actions = array('edit', 'delete');
        $helper->bulk_actions = array(
            'delete' => array(
                'text' => $this->l('Delete selected'),
                'icon' => 'icon-trash',
                'confirm' => $this->l('Delete selected items?')
            )
        );
        $helper->listTotal = count(AddifyrequestaquoteClass::getListContent());
        $helper->show_toolbar = true;
        $helper->toolbar_btn['new'] =  array(
            'href' => AdminController::$currentIndex.'&configure='.$this->name.'&add'.$this->name.'&token='.Tools::getAdminTokenLite('AdminModules').'&rulesaddifyrequestaquote',
            'desc' => $this->l('Add new')
        );

        $helper->title = $this->displayName.' Rules';
        $helper->table = $this->name;
        $helper->token = Tools::getAdminTokenLite('AdminModules');
        $helper->currentIndex = AdminController::$currentIndex.'&configure='.$this->name.'&rulesaddifyrequestaquote';
        return $helper->generateList(AddifyrequestaquoteClass::getListContent(), $fields_list);
    }

    protected function renderQuoteMessageList()
    {
        $fields_list = array(
            'id_quotemessage' => array(
                'title' => $this->l('ID'),
                'width' => 120,
                'type' => 'text',
                'search' => false,
                'orderby' => false
            ),
            'quote_id' => array(
                'title' => $this->l('Quote ID'),
                'width' => 140,
                'type' => 'text',
                'search' => false,
                'orderby' => false
            ),
            // 'quote_name' => array(
            //     'title' => $this->l('Quote Name'),
            //     'width' => 140,
            //     'type' => 'text',
            //     'search' => false,
            //     'orderby' => false
            // ),
            'customer_name' => array(
                'title' => $this->l('Customer Name'),
                'width' => 140,
                'type' => 'text',
                'search' => false,
                'orderby' => false
            ),
            'email' => array(
                'title' => $this->l('Email'),
                'width' => 140,
                'type' => 'text',
                'search' => false,
                'orderby' => false
            ),
            // 'unreadmsg' => array(
            //     'title' => $this->l('Unread Messages'),
            //     'width' => 140,
            //     'type' => 'text',
            //     'search' => false,
            //     'orderby' => false
            // ),
            'date_add' => array(
                'title' => $this->l('Added Date'),
                'width' => 140,
                'type' => 'date',
                'search' => false,
                'orderby' => false
            ),
            // 'date_upd' => array(
            //     'title' => $this->l('Update Date'),
            //     'width' => 140,
            //     'type' => 'date',
            //     'search' => false,
            //     'orderby' => false
            // ),
        );

        $helper = new HelperList();
        $helper->shopLinkType = '';
        $helper->simple_header = false;
        $helper->identifier = 'id_quotemessage';
        $helper->actions = array('view');
        // /
        $helper->listTotal = count(AddifyQuoteAllMessageClass::getListContent());
        $helper->show_toolbar = true;
        $helper->title = $this->l('All Messages');
        $helper->table = 'addifyrfqallmessages';
        $helper->token = Tools::getAdminTokenLite('AdminModules');
        $helper->currentIndex = AdminController::$currentIndex.'&configure='.$this->name.'&quotemessageaddifyrequestaquote';
        return $helper->generateList(AddifyQuoteAllMessageClass::getListContent(), $fields_list);
    }

    protected function renderRequestList()
    {
        $fields_list = array(
            'id_addifyrequestaquote' => array(
                'title' => $this->l('ID'),
                'width' => 120,
                'type' => 'text',
                'search' => false,
                'orderby' => false
            ),
            'quote_name' => array(
                'title' => $this->l('Quote Name'),
                'width' => 140,
                'type' => 'text',
                'search' => false,
                'orderby' => false
            ),
            'status' => array(
                'title' => $this->l('Status'),
                'width' => 140,
                'type' => 'text',
                'search' => false,
                'orderby' => false
            ),
            'name' => array(
                'title' => $this->l('Customer Name'),
                'width' => 140,
                'type' => 'text',
                'search' => false,
                'orderby' => false
            ),
            'adminnote' => array(
                'title' => $this->l('Admin Note'),
                'width' => 140,
                'type' => 'text',
                'search' => false,
                'orderby' => false
            ),
            'date_add' => array(
                'title' => $this->l('Added Date'),
                'width' => 140,
                'type' => 'datetime',
                'search' => false,
                'orderby' => false
            ),
            'date_upd' => array(
                'title' => $this->l('Update Date'),
                'width' => 140,
                'type' => 'datetime',
                'search' => false,
                'orderby' => false
            ),
        );

        // multishop feature
        if (Shop::isFeatureActive()) {
            $this->fields_list['id_shop'] = array(
                'title' => $this->l('ID Shop'),
                'align' => 'center',
                'width' => 25,
                'type' => 'int'
            );
        }

        $helper = new HelperList();
        $helper->shopLinkType = '';
        $helper->simple_header = false;
        $helper->identifier = 'id_addifyrequestaquote';
        $helper->toolbar_btn['new'] =  array(
            'href' => AdminController::$currentIndex.'&configure='.$this->name.'&addquotation'.$this->name.'&token='.Tools::getAdminTokenLite('AdminModules').'&quotationsaddifyrequestaquote',
            'desc' => $this->l('Add new')
        );
        $helper->actions = array('edit', 'delete');
        $helper->bulk_actions = array(
            'delete' => array(
                'text' => $this->l('Delete selected'),
                'icon' => 'icon-trash',
                'confirm' => $this->l('Delete selected items?')
            )
        );
        $helper->listTotal = count(AddifyrequestsallClass::getListContent());
        $helper->show_toolbar = true;
        $helper->title = $this->l('All Quotes');
        $helper->table = 'addifyrequestsall';
        $helper->token = Tools::getAdminTokenLite('AdminModules');
        $helper->currentIndex = AdminController::$currentIndex.'&configure='.$this->name.'&quotationsaddifyrequestaquote';
        return $helper->generateList(AddifyrequestsallClass::getListContent(), $fields_list);
    }

    protected function renderQuotationForm()
    {   
        // ------------ Customer address 
        $customer_address_here = [];
        foreach (Customer::getCustomers() as $customer) {
            $customer_obj = new Customer((int)$customer['id_customer']);
            if (Validate::isLoadedObject($customer_obj)) {
                $customer_id = $customer['id_customer'];
                $addresses = $customer_obj->getAddresses((int)Configuration::get('PS_LANG_DEFAULT'));
                foreach ($addresses as $address) {
                    $customer_address_here[] = [
                        'id' => $customer_id, 
                        'name' => "Address: {$address['address1']}, {$address['city']}, {$address['country']}, {$address['postcode']}", 
                    ];
                }
            }
        }

        // ----------- Carrier 
        $carriers = Carrier::getCarriers(Context::getContext()->language->id, true);
        if ($carriers) {
            $active_shipping_here = array();
            foreach ($carriers as $carrier) {
                $active_shipping_here[] = array(
                    'id' => $carrier['id_carrier'],
                    'name' => $carrier['name']
                );
            }
        }

        // ---------------- Discount
        $id_lang = Context::getContext()->language->id;
        $getProdDiscount = Db::getInstance()->executeS('SELECT cr.id_cart_rule, crl.name, cr.code 
            FROM `'._DB_PREFIX_.'cart_rule` cr
            INNER JOIN `'._DB_PREFIX_.'cart_rule_lang` crl ON cr.id_cart_rule = crl.id_cart_rule
            WHERE crl.id_lang = '.(int)$id_lang.'
        ');

        $discount_options = array();

        if (!empty($getProdDiscount)) {
            foreach ($getProdDiscount as $discount) {
                $discount_options[] = array(
                    'id' => $discount['id_cart_rule'],
                    'name' => $discount['name'],
                    'name' => $discount['name'] .  ' (' . $discount['code'] . ')'
                );
            }
        }
        

        $fields_form = array(
            'form' => array(
                'legend' => array(
                    'title' => $this->l('Add quote'),
                    'icon' => 'icon-cogs',
                ),
                'input' => array(
                    array(
                        'type' => 'hidden',
                        'name' => 'id_addifyrequestaquote'
                    ),
                    array(
                        'type' => 'text',
                        'label' => $this->l('Quote Name'),
                        'name' => 'quote_name',
                        'desc' => $this->l("Write a quote name here"),
                        'col' => 6,
                    ),
                    array(
                        'type' => 'araq_customers',
                        'label' => $this->l('Customers'),
                        'name' => 'araq_customer',
                        'required' => true,
                        'prefix' => '<i class="icon-search"></i>',
                        'hint' => $this->l('Search and add Customer(s) which you want for Quote.')
                    ),
                    array(
                        'type' => 'select',
                        'label' => $this->l('Customer address'),
                        'name' => 'customer_address_field',
                        'id' => 'customer_address_field',
                        'desc' => $this->l("Select the customer's address for the admin quotation"),  
                        'options' => array(
                            'query' => $customer_address_here,
                            'id' => 'id',
                            'name' => 'name',
                        ),
                    ),
                    array(
                        'type' => 'araq_products',
                        'label' => $this->l('Products'),
                        'name' => 'araq_product',
                        'required' => true,
                        'prefix' => '<i class="icon-search"></i>',
                        'hint' => $this->l('Search and add product(s) which you want for Quote.')
                    ),

                    array(
                        'type' => 'select',
                        'label' => $this->l('Available Discounts'), 
                        'name' => 'quote_product_discount', 
                        'desc' => $this->l('Select discount for the Quote'),
                        'options' => array(
                            'query' => $discount_options, 
                            'id' => 'id',
                            'name' => 'name',
                        ),
                    ),

                    array(
                        'type' => 'select',
                        'label' => $this->l('Shipping'),
                        'name' => 'shipping_field',
                        'id' => 'shipping_field',
                        'desc' => $this->l('Select shipping for the Quote'),  
                        'options' => array(
                            'query' => $active_shipping_here,
                            'id' => 'id',
                            'name' => 'name',
                        ),
                    ),
                ),
                'submit' => array(
                    'title' => $this->l('Save'),
                ),
                'buttons' => array(
                    'cancel' => array(
                        'title' => $this->l('Cancel'),
                        'class' => 'btn btn-default',
                        'icon' => 'process-icon-cancel',
                        'href' => AdminController::$currentIndex.'&configure='.$this->name.'&token='.Tools::getAdminTokenLite('AdminModules').'&quotationsaddifyrequestaquote',
                    ),
                )
            ),
        );

        $helper = new HelperForm();
        $helper->show_toolbar = false;
        $helper->show_cancel_button = false;
        $helper->table = 'addifyrequestsall';
        $helper->module = $this;
        $helper->default_form_language = $this->context->language->id;
        $helper->allow_employee_form_lang = Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG', 0);
        $helper->identifier = 'id_addifyrequestaquote';
        $helper->submit_action = 'Submitquotation'.$this->name;
        $helper->currentIndex = AdminController::$currentIndex.'&configure='.$this->name.'&quotationsaddifyrequestaquote';
        $helper->token = Tools::getAdminTokenLite('AdminModules');
        $helper->back_url = $helper->currentIndex.'&token='.$helper->token;
        $araq_customers = array();
        $araq_products = array();
        $pro_val = array();
        $product_values_full = '';

        if (Tools::getValue('id_addifyrequestaquote')) {
            $hidepriceBlock_1 = new AddifyrequestsallClass((int)Tools::getValue('id_addifyrequestaquote'));
            $post_accessories_tab_1 = explode(',', $hidepriceBlock_1->id_customer);
            foreach ($post_accessories_tab_1 as $id_pro) {

                if (!$this->haveThiscustomer($id_pro, $araq_customers) &&
                    $product_1 = AddifyrequestsallClass::getCustomerById($id_pro)) {
                    $araq_customers[] = $product_1;
                }
            }
        } else {
            $araq_customers = array();
        }
        if ($post_accessories_1 = Tools::getValue('inputRestrictedProducts_1')) {
            $post_accessories_tab_1 = explode('-', $post_accessories_1);
            foreach ($post_accessories_tab_1 as $id_pro) {
                if (!$this->haveThiscustomer($id_pro, $araq_customers) &&
                    $product_1 = AddifyrequestsallClass::getCustomerById($id_pro)) {
                    $araq_customers[] = $product_1;
                }
            }
        }

        if (Tools::getValue('id_addifyrequestaquote')) {
            $obj2 = new AddifyrequestsallClass((int)Tools::getValue('id_addifyrequestaquote'));
            if ($obj2->product) {
                $post_accessories_tab_2 = explode(',', $obj2->id_product);
                foreach ($post_accessories_tab_2 as $key =>  $productdetails) {
                    $exp_idss = explode('-', $productdetails);
                    $id_product = $exp_idss[0];
                    if (isset($exp_idss[1])) {
                        $id_product_attribute = $exp_idss[1];
                    }else{
                        $id_product_attribute = 0;
                    }
                    $combinations = Product::getAttributesParams($id_product, $id_product_attribute);
                    $product_attribute = '';
                    $product_reference = '';
                    foreach ($combinations as $combination) {
                        $product_reference = $combination['reference'];
                        $product_attribute = $product_attribute."-".$combination['name'];
                    }
                    if (!$this->haveThisProductByCombination($id_product,$id_product_attribute,$araq_products) &&
                        $araq_products[] = AddifyrequestsallClass::getProductById($id_product,$id_product_attribute,$productdetails,$product_attribute,$product_reference)) {
                    }
                }

                $product_values_full = $obj2->product_values;
                $product_values = explode(',', $obj2->product_values);

                foreach ($product_values as $key => $product_value) {
                    if ($product_value) {
                     
                        $pro_values = [];
                        $pro_values = explode('-', $product_value);
                        
                        $pro_val[$pro_values[0]]['min'] = $pro_values[2];
                    }
                }
            }
        } else {
            if ($post_accessories_2 = Tools::getValue('inputRestrictedProducts_2')) {
                $post_accessories_tab_2 = explode('-', $post_accessories_2);
                foreach ($post_accessories_tab_2 as $id_product) {
                    $exp_idss = explode('-', $id_product);
                    $id_product = $exp_idss[0];
                    $id_product_attribute = $exp_idss[1];
                    if (!$this->haveThisProductByCombination($id_product,$id_product_attribute, $araq_products) &&
                        $product = AddifyrequestsallClass::getProductById($id_product)) {
                        $araq_products[] = $product;
                        $araq_products['id_product'] = $id_product; 
                        $araq_products['id_product_attribute'] = $id_product_attribute;
                    }
                }    
            }
        }

        $helper->tpl_vars = array(
            'fields_value' => $this->getQuotationsFormValues(), /* Add values for your inputs */
            'languages' => $this->context->controller->getLanguages(),
            'id_language' => $this->context->language->id,
            'araq_products' => $araq_products,
            'araq_customers' => $araq_customers,
            'pro_val' => $pro_val,
            'product_values_full' => $product_values_full,
            'context_link' => Context::getContext()->link,
        );

        return $helper->generateForm(array($fields_form));
    }

    public function haveThisProductByCombination($id_product,$id_product_attribute,$products)
    {
        foreach ($products as $product) {
            if ((int)$product['id_product'] == (int)$id_product && (int)$product['id_product_attribute'] == (int)$id_product_attribute) {
                return true;
            }
        }
        return false;
    }

    public function haveThiscustomer($id_product, $products)
    {
        foreach ($products as $product) {
            if ((int)$product['id_customer'] == (int)$id_product) {
                return true;
            }
        }
        return false;
    }

    protected function getQuotationsFormValues()
    {
        $fields_value = array();
        $languages = Language::getLanguages();

        if (Tools::getValue('id_addifyrequestaquote') && (Tools::isSubmit('Submitquotation'.$this->name) === false)) {
            $postBlock = new AddifyrequestsallClass((int)Tools::getValue('id_addifyrequestaquote'));
            $fields_value['id_addifyrequestaquote'] = $postBlock->id_addifyrequestaquote;
            $fields_value['araq_product'] = $postBlock->id_product;
            $fields_value['quote_name'] = $postBlock->quote_name;
            $fields_value['araq_customer'] = $postBlock->id_customer;
            $fields_value['customer_address_field'] = explode(',', $postBlock->customer_address_field);
            $fields_value['quote_product_discount'] = explode(',', $postBlock->quote_product_discount);
            $fields_value['shipping_field'] = $postBlock->shipping_field;
        }
        else {
            $allpids = [];
            $allpattr = [];
            $allpqty = [];
            $allpname = [];
            $allpsku = [];
            $allpimages = [];
            $allpinfo = [];
            $ids_attrs = '';
            $allProducts=[];
            $productOne=[];
            $allitems2='';
            $allitems = '';
            $Customer_name = '';
            $Customer_email = '';

            $id_prod_details = Tools::getValue('araq_product');

            $productQty = Tools::getValue('product_values'); // qty
            if ($productQty) {
                $productsQty = explode(",", $productQty);
                $productQuantities = [];
                foreach ($productsQty as $pair) {
                    $pair_values = explode("-", $pair);
                    $productQuantities[$pair_values[0]] = $pair_values[1];
                }
            }

            if ($id_prod_details) {
                foreach($id_prod_details as $key => $id_prod_detail) {

                   $id_prod_detail = explode('-',$id_prod_detail);
                   $id_product = (int)$id_prod_detail[0];
                   $id_product_attribute = (int)$id_prod_detail[1];

                    $product = new Product($id_product);
                    $productName = $product->name;
                    $productOne['id'] = $id_product;
                    $productOne['id_attr'] = $id_product_attribute;
                    
                    if (isset($productQuantities[$id_product])) {
                        $productOne['qty'] = $productQuantities[$id_product];
                    } else {
                        $productOne['qty'] = 0; 
                    }

                    $productOne['name'] = $productName[1];
                    $productOne['SKU'] = $product->reference;
                    $id_image = Product::getCover($id_product);
                    $image = new Image($id_image['id_image']);
                    $image_url = _PS_BASE_URL_._THEME_PROD_DIR_.$image->getExistingImgPath().".jpg";
                    $productOne['image'] = $image_url;

                    $info = '';
                    $combinations = $product->getAttributeCombinations($this->context->language->id);
                    foreach ($combinations as $onep) {
                        if($onep['id_product_attribute'] == $id_product_attribute) {
                            $info = $onep['attribute_name'].' '.$info;
                        }
                    }
                    $productOne['info'] = $info;
                    array_push($allProducts, $productOne);
                }

                foreach ($allProducts as $oneProduct) {
                    array_push($allpids, $oneProduct['id']);
                    array_push($allpattr, $oneProduct['id_attr']);
                    array_push($allpqty, $oneProduct['qty']);
                    array_push($allpname, $oneProduct['name']);
                    array_push($allpsku, $oneProduct['SKU']);
                    array_push($allpimages, $oneProduct['image']);
                    array_push($allpinfo, $oneProduct['info']);       
                }

                $allpids=implode(',', $allpids);
                $allpattr=implode(',', $allpattr);
                $allpqty=implode(',', $allpqty);
                $allpname=implode(',', $allpname);
                $allpsku=implode(',', $allpsku);
                $allpimages=implode(',', $allpimages);
                $allpinfo=implode(',', $allpinfo);

                $org_priceid = explode(',',$allpids);
                $org_priceidattr = explode(',', $allpattr);
                $allitems = explode(',',$allpids);
                $itemscount = count($allitems);
                for($i=0;$i<$itemscount;$i++) {                    
                    $org_price=Product::getPriceStatic($org_priceid[$i], false, $org_priceidattr[$i], 2);
                    if($i==0){
                        $allitems='1';
                        $allitems2=$org_price;
                    } else {
                        $allitems=$allitems.',1';
                        $allitems2=$allitems2.','.$org_price;
                    }  
                }

                if (!Tools::getValue('araq_product')) {
                    $fields_value['id_product'] = Tools::getValue('araq_product');
                } else {
                    $fields_value['id_product'] = $allpids;
                }

                if (!Tools::getValue('product_values')) { // qty
                    $fields_value['quantity'] = Tools::getValue('product_values');
                } else {
                    $fields_value['quantity'] = $allpqty;
                }

                // ----------------- Discount --------------------------------------
                // $id_products = Tools::getValue('araq_product') ? Tools::getValue('araq_product') : $allpids;
                // if (is_string($id_products)) {
                //     $id_products = explode(',', $id_products);
                // }

                // $discounts = [];
                // if (!empty($id_products)) {
                //     foreach ($id_products as $id_product) {
                //         $id_product = (int)$id_product;

                //         $product = new Product($id_product, false, Context::getContext()->language->id);
                //         $id_product_attribute = null;

                //         $PRICE_WITH_T = Product::getPriceStatic($id_product, true, $id_product_attribute);
                //         $PRICE_WITHOUT_T = Product::getPriceStatic($id_product, false, $id_product_attribute);
                        
                //         $PRICE_WITH_D = Product::getPriceStatic($id_product, true, $id_product_attribute, 6, null, false, true);
                //         $PRICE_WITHOUT_D = Product::getPriceStatic($id_product, true, $id_product_attribute, 6, null, false, false);
                        
                //         $tax = $PRICE_WITH_T - $PRICE_WITHOUT_T;
                //         $discount_value = $PRICE_WITHOUT_D - $PRICE_WITH_D;

                //         $discounts[$id_product] = $discount_value;
                //     }
                // }

                // $discounts_string = '';
                // foreach ($discounts as $id_product => $discount) {
                //     $discounts_string .= number_format($discount, 2) . ',';
                // }

                // $discounts_string = rtrim($discounts_string, ',');
                // $fields_value['quote_product_discount'] = $discounts_string;
            // -------------------------------------------------------
            }

            $id_addifyrequestaquote = Tools::getValue('id_addifyrequestaquote');
            if (!empty($id_addifyrequestaquote)) {
                $fields_value['id_addifyrequestaquote'] = $id_addifyrequestaquote;
            } else {
                $fields_value['id_addifyrequestaquote'] = null;
            }

            $idCustomer = Tools::getValue('araq_customer');
            if (!empty($idCustomer) && is_array($idCustomer)) {
                $Customer = new Customer($idCustomer[0]);
                $fields_value['id_customer'] = $Customer->id;
                $fields_value['name'] = $Customer->firstname.$Customer->lastname;
                $fields_value['email'] = $Customer->email;
            } else {
                $fields_value['id_customer'] = null;
                $fields_value['name'] = null;
                $fields_value['email'] = null;
            }

            $fields_value['description'] = Tools::getValue('description');
            $fields_value['offered_price'] = Tools::getValue('offered_price');
            $fields_value['status'] = 'Pending';
            $fields_value['id_product_attribute'] = $allpattr;
            $fields_value['product_info'] = $allpinfo;
            $fields_value['product_image'] = $allpimages;
            $fields_value['product_name'] = $allpname;
            $fields_value['product_sku'] = $allpsku;
            $fields_value['quote_name'] = Tools::getValue('quote_name');
            
            $fields_value['customer_address_field'] = Tools::getValue('customer_address_field');
            if ($fields_value['customer_address_field']) {
                $getCustomerAddressThroughId = AddifyrequestsallClass::getCustomerAddress($fields_value['customer_address_field']);
                $fields_value['customer_address_field'] = $getCustomerAddressThroughId;
            }
            
            $fields_value['quote_product_discount'] = Tools::getValue('quote_product_discount');
            if ($fields_value['quote_product_discount']) {
                $getQuoteDiscountThroughId = AddifyrequestsallClass::getProdDiscount($fields_value['quote_product_discount']);
                $fields_value['quote_product_discount'] = $getQuoteDiscountThroughId;
            }

            $fields_value['shipping_field'] = Tools::getValue('shipping_field');
            if ($fields_value['shipping_field']) {
                $getQuoteShippingThroughId = AddifyrequestsallClass::getShippingAddress($fields_value['shipping_field']);
                $fields_value['shipping_field'] = $getQuoteShippingThroughId;
            }

            $fields_value['admin_price'] = $allitems;
            $fields_value['original_price'] = $allitems2;
        }
        return $fields_value;
    }

    protected function processQuotationsSave()
    {
        $call_back = 'add';
        $form_values = $this->getQuotationsFormValues();

        if (!isset($form_values['id_customer']) || empty($form_values['id_customer'])) {
            $this->context->controller->errors[] = $this->l('Please fill the required customer field.');
        }

        if (!isset($form_values['id_product']) || empty($form_values['id_product'])) {
            $this->context->controller->errors[] = $this->l('Please fill the required product search field.');
        }

        if (count($this->context->controller->errors)) {
            return $this->context->controller->errors;
        }

        $dt = date("Y-m-d h:i:s");
        if (($id_addifyrequestaquote = Tools::getValue('id_addifyrequestaquote'))) {
            $call_back = 'update';
            $AddifyrequestsallClass= new AddifyrequestsallClass((int)$id_addifyrequestaquote);
            $AddifyrequestsallClass->date_upd = $dt;
        } else {
            $AddifyrequestsallClass = new AddifyrequestsallClass();
            $AddifyrequestsallClass->date_add = $dt;
        }

        $AddifyrequestsallClass->id_customer = $form_values['id_customer'];
        $AddifyrequestsallClass->status = $form_values['status'];
        $AddifyrequestsallClass->id_product = $form_values['id_product'];
        $AddifyrequestsallClass->id_product_attribute = $form_values['id_product_attribute'];
        $AddifyrequestsallClass->product_info = $form_values['product_info'];
        $AddifyrequestsallClass->product_name = $form_values['product_name'];
        $AddifyrequestsallClass->product_sku = $form_values['product_sku'];
        $AddifyrequestsallClass->product_image = $form_values['product_image'];
        $AddifyrequestsallClass->quantity = $form_values['quantity'];
        $AddifyrequestsallClass->offered_price = $form_values['offered_price'];
        $AddifyrequestsallClass->original_price = $form_values['original_price']; 
        $AddifyrequestsallClass->name = $form_values['name'];
        $AddifyrequestsallClass->email = $form_values['email'];
        $AddifyrequestsallClass->description = $form_values['description'];
        $AddifyrequestsallClass->quote_name = $form_values['quote_name'];
        $AddifyrequestsallClass->customer_address_field = $form_values['customer_address_field'];
        $AddifyrequestsallClass->quote_product_discount = $form_values['quote_product_discount'];
        $AddifyrequestsallClass->shipping_field = $form_values['shipping_field'];
        $AddifyrequestsallClass->admin_price = $form_values['admin_price'];

        if (!call_user_func(array($AddifyrequestsallClass, $call_back))) {
            $this->context->controller->errors = sprintf($this->l('Something went wrong while performing operation %s'), $call_back);
        } else {
            $this->flushCache();

           $this->quoteSavedSendEmail($AddifyrequestsallClass); // when quote submitted so send data to the customer
           
            if($call_back=='add') {
                Tools::redirectAdmin($this->context->link->getAdminLink('AdminModules', true) . '&conf=3&configure=' . $this->name . '&tab_module=' . $this->tab . '&module_name=' . $this->name.'&quotationsaddifyrequestaquote');
            }
            else {
                Tools::redirectAdmin($this->context->link->getAdminLink('AdminModules', true) . '&conf=4&configure=' . $this->name . '&tab_module=' . $this->tab . '&module_name=' . $this->name.'&quotationsaddifyrequestaquote');
            } 
        }
    }

    /**
     * Create the form that will be displayed in the configuration of your module.
     */
    protected function renderForm()
    {
        $helper = new HelperForm();

        $helper->show_toolbar = false;
        $helper->show_cancel_button = false;
        $helper->table = 'addifyrequestaquote';
        $helper->module = $this;
        $helper->default_form_language = $this->context->language->id;
        $helper->allow_employee_form_lang = Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG', 0);

        $helper->identifier = 'id_'.$this->table;
        $helper->submit_action = 'submitAddifyrequestaquote';
        $helper->currentIndex = AdminController::$currentIndex.'&configure='.$this->name.'&rulesaddifyrequestaquote';
        $helper->token = Tools::getAdminTokenLite('AdminModules');
        $helper->back_url = $helper->currentIndex.'&token='.$helper->token;
        $products = array();

        if (Tools::getValue('id_addifyrequestaquote')) {
            $hidepriceBlock = new AddifyrequestaquoteClass((int)Tools::getValue('id_addifyrequestaquote'));
            $post_accessories_tab = explode(',', $hidepriceBlock->product);
            foreach ($post_accessories_tab as $id_product) {
                if (!$this->haveThisProduct($id_product, $products) &&
                    $product = AddifyrequestaquoteClass::getProductById($id_product)) {
                    $products[] = $product;
                }
            }
        } else {
            $products = array();
        }
        if ($post_accessories = Tools::getValue('inputRestrictedProducts')) {
            $post_accessories_tab = explode('-', $post_accessories);
            foreach ($post_accessories_tab as $id_product) {
                if (!$this->haveThisProduct($id_product, $products) &&
                    $product = AddifyrequestaquoteClass::getProductById($id_product)) {
                    $products[] = $product;
                }
            }
        }

        $helper->tpl_vars = array(
            'fields_value' => $this->getConfigFormValues(), /* Add values for your inputs */
            'languages' => $this->context->controller->getLanguages(),
            'id_language' => $this->context->language->id,
            'products' => $products,
            'context_link' => Context::getContext()->link,
        );

        return $helper->generateForm(array($this->getConfigForm()));
    }
    public function haveThisProduct($id_product, $products)
    {
        foreach ($products as $product) {
            if ((int)$product['id_product'] == (int)$id_product) {
                return true;
            }
        }
        return false;
    }

    /**
     * Create the structure of your form.
     */
    protected function getConfigForm()
    {
        $access_type = array(
            array('id' => '1', 'name' => $this->l('All Product')),
            array('id' => '2', 'name' => $this->l('Selected Product')),
        );

        if (Tools::getValue('id_addifyrequestaquote')) {
            $hidepriceBlock = new AddifyrequestaquoteClass((int)Tools::getValue('id_addifyrequestaquote'));
            $selected_categories = explode(',', $hidepriceBlock->categories);
        } else {
            $selected_categories = array();
        }

        if (Shop::isFeatureActive()) {
            $this->fields_form['input'][] = array(
                'type' => 'shop',
                'label' => $this->l('Shop association'),
                'name' => 'checkBoxShopAsso',
            );
        }

        // Getting Manufacturers
        $Manufacturers_array = Manufacturer::getManufacturers(false,$this->context->language->id, false, false, false);
        $Manufacturers = array();

        foreach ($Manufacturers_array as $Manufacturer) {
            
            $Manufacturers[] = array('name' => $Manufacturer['name'], 'id' => $Manufacturer['id_manufacturer']);
        }
        
        // Getting Suppliers
        $Suppliers_array = Supplier::getSuppliers(false, $this->context->language->id, false, false, false, false);
        $Suppliers = array();

        foreach ($Suppliers_array as $Supplier) {
            
            $Suppliers[] = array('name' => $Supplier['name'], 'id' => $Supplier['id_supplier']);
        }

        return array(
            'form' => array(
                'legend' => array(
                    'title' => $this->l('Create Rule'),
                    'icon' => 'icon-cogs',
                ),
                'input' => array(
                    array(
                        'type' => 'hidden',
                        'name' => 'id_addifyrequestaquote'
                    ),
                    array(
                        'type'          => 'text',
                        'label'         => $this->l('Title'),
                        'name'          => 'title',
                        'desc' => $this->l('Enter rule title '),
                    ),
                    array(
                        'type'          => 'text',
                        'label'         => $this->l('Priority'),
                        'name'          => 'priority',
                        'desc' => $this->l('Set rule priority'),
                    ),
                    array(
                        'type' => 'switch',
                        'label' => $this->l('Active'),
                        'name' => 'active',
                        'is_bool' => true,
                        'desc' => $this->l('Enable request a quote rule'),
                        'values' => array(
                            array(
                                'id' => 'active_on',
                                'value' => true,
                                'label' => $this->l('Enabled')
                            ),
                            array(
                                'id' => 'active_off',
                                'value' => false,
                                'label' => $this->l('Disabled')
                            )
                        ),
                    ),
                    array(
                        'type' => 'switch',
                        'label' => $this->l('Hide Price'),
                        'name' => 'hideprice',
                        'desc' => $this->l('Enable/Disable to hide price of products '),
                        'values' => array(
                            array(
                                'id' => 'active_on',
                                'value' => 1,
                                'label' => $this->l('Enabled')
                            ),
                            array(
                                'id' => 'active_off',
                                'value' => 0,
                                'label' => $this->l('Disabled')
                            )
                        ),
                    ),
                    array(
                        'type' => 'switch',
                        'label' => $this->l('Hide Add to Cart Button'),
                        'desc' => $this->l('Enable/Disable hide add to cart button on products'),
                        'name' => 'hidecart',
                        'values' => array(
                            array(
                                'id' => 'active_on',
                                'value' => 1,
                                'label' => $this->l('Enabled')
                            ),
                            array(
                                'id' => 'active_off',
                                'value' => 0,
                                'label' => $this->l('Disabled')
                            )
                        ),
                    ),
                    array(
                        'type'          => 'color',
                        'label'         => $this->l('Button Text Color :'),
                        'name'          => 'text_color',
                        'desc' => $this->l('Select request a quote button text color'),
                    ),
                    array(
                        'type'          => 'color',
                        'label'         => $this->l('Button Background Color :'),
                        'name'          => 'text_bg_color',
                        'desc' => $this->l('Select request a quote button background color'),
                    ),
                    array(
                        'type' => 'text',
                        'label' => $this->l('Button Text'),
                        'name' => 'message',
                        'desc' => $this->l('Enter button text that will appear on request a quote button on frontend'),
                    ),
                    array(
                        'type' => 'switch',
                        'label' => $this->l('User Group Selection'),
                        'name' => 'group_active',
                        'desc' => $this->l('Enable/Disable user group selection'),
                        'is_bool' => true,
                        'values' => array(
                            array(
                                'id' => 'active_on',
                                'value' => true,
                                'label' => $this->l('Enabled')
                            ),
                            array(
                                'id' => 'active_off',
                                'value' => false,
                                'label' => $this->l('Disabled')
                            )
                        ),
                    ),
                    array(
                        'type' => 'group',
                        'label' => $this->l('User Group'),
                        'name' => 'groupBox',
                        'values' => Group::getGroups(Context::getContext()->language->id),
                        'info_introduction' => $this->l('You now have three default customer groups.'),
                        'desc' => $this->l('Mark any/all of the customer group(s) which you would like to show Request A Quote.'),
                    ),
                    array(
                        'type' => 'select',
                        'label' => $this->l('Product type'),
                        'name' => 'type',
                        'desc' => $this->l('Select product type'),
                        'options' => array(
                            'query' => $access_type,
                            'id' => 'id',
                            'name' => 'name'
                        ),
                        'col' => 2,
                    ),
                    array(
                        'type' => 'switch',
                        'label' => $this->l('Product Selection'),
                        'name' => 'product_active',
                        'desc' => $this->l('Enable/Disable product selection'),
                        'is_bool' => true,
                        'values' => array(
                            array(
                                'id' => 'active_on',
                                'value' => true,
                                'label' => $this->l('Enabled')
                            ),
                            array(
                                'id' => 'active_off',
                                'value' => false,
                                'label' => $this->l('Disabled')
                            )
                        ),
                    ),
                    array(
                        'type' => 'addifydisclaimer_product',
                        'label' => $this->l('Search Product'),
                        'name' => 'product',
                        'col' => 6,
                        'desc' => $this->l('Search and Add product(s) here on which you would like to show request a quote'),
                        'prefix' => '<i class="icon-search"></i>',
                        'hint' => $this->l('Request a quote button will shown for selected product.')
                    ),
                    array(
                        'type' => 'switch',
                        'label' => $this->l('Category Selection'),
                        'name' => 'category_active',
                        'desc' => $this->l('Enable/Disable category selection'),
                        'is_bool' => true,
                        'values' => array(
                            array(
                                'id' => 'active_on',
                                'value' => true,
                                'label' => $this->l('Enabled')
                            ),
                            array(
                                'id' => 'active_off',
                                'value' => false,
                                'label' => $this->l('Disabled')
                            )
                        ),
                    ),
                    array(
                        'type'  => 'categories',
                        'label' => $this->l('Categories'),
                        'name'  => 'category',
                        'desc' => $this->l('Choose category(s) here on which you would like to show request a quote'),
                        'col' => 6,
                        'tree'  => array(
                            'id' => 'type_category',
                            'use_checkbox' => true,
                            'disabled_categories' => null,
                            'selected_categories' => $selected_categories,
                            'root_category' => Context::getContext()->shop->getCategory()
                        )
                    ),
                    array(
                        'type' => 'switch',
                        'label' => $this->l('Supplier Selection'),
                        'name' => 'supplier_active',
                        'desc' => $this->l('Enable/Disable supplier selection'),
                        'is_bool' => true,
                        'values' => array(
                            array(
                                'id' => 'active_on',
                                'value' => true,
                                'label' => $this->l('Enabled')
                            ),
                            array(
                                'id' => 'active_off',
                                'value' => false,
                                'label' => $this->l('Disabled')
                            )
                        ),
                    ),
                    array(
                        'type' => 'select',
                        'label' => $this->l('Supplier'),
                        'name' => 'Supplier',
                        'id' => 'Supplier',
                        'multiple' => true,
                        'desc' => $this->l('Choose supplier(s) here on which you would like to show request a quote'),
                        'options' => array(
                            'query' => $Suppliers,
                            'id' => 'id',
                            'name' => 'name',
                        ),
                        
                    ),
                    array(
                        'type' => 'switch',
                        'label' => $this->l('Manufacturer Selection'),
                        'name' => 'manufacturer_active',
                        'desc' => $this->l('Enable/Disable manufacturer selection'),
                        'is_bool' => true,
                        'values' => array(
                            array(
                                'id' => 'active_on',
                                'value' => true,
                                'label' => $this->l('Enabled')
                            ),
                            array(
                                'id' => 'active_off',
                                'value' => false,
                                'label' => $this->l('Disabled')
                            )
                        ),
                    ),
                    array(
                        'type' => 'select',
                        'label' => $this->l('Manufacturer'),
                        'name' => 'Manufacturer',
                        'id' => 'Manufacturer',
                        'multiple' => true,
                        'desc' => $this->l('Choose manufacturer(s) here on which you would like to show request a quote'),
                        'options' => array(
                            'query' => $Manufacturers,
                            'id' => 'id',
                            'name' => 'name',
                        ),
                        
                    ),
                ),
                'submit' => array(
                    'title' => $this->l('Save'),
                ),
                'buttons' => array(
                    'cancel' => array(
                        'title' => $this->l('Cancel'),
                        'class' => 'btn btn-default',
                        'icon' => 'process-icon-cancel',
                        'href' => AdminController::$currentIndex.'&configure='.$this->name.'&token='.Tools::getAdminTokenLite('AdminModules').'&rulesaddifyrequestaquote',
                    ),
                )
            ),
        );
    }

   
    /**
     * Set values for the inputs.
     */
    protected function getConfigFormValues()
    {
        $fields_value = array();
        $accessed_groups_ids = array();

        if (Tools::getValue('id_addifyrequestaquote') && (Tools::isSubmit('submitAddifyrequestaquote') === false)) {
            $hidepriceBlock = new AddifyrequestaquoteClass((int)Tools::getValue('id_addifyrequestaquote'));
            $fields_value['id_addifyrequestaquote'] = $hidepriceBlock->id;
            $fields_value['title'] = $hidepriceBlock->title;
            $fields_value['active'] = $hidepriceBlock->active;
            $fields_value['groupBox'] = explode(',', $hidepriceBlock->groups);
            $fields_value['type'] = $hidepriceBlock->product_type;
            $fields_value['product'] = explode(',', $hidepriceBlock->product);
            $fields_value['priority'] = $hidepriceBlock->priority;
            $fields_value['category'] = explode(',', $hidepriceBlock->categories);
            $accessed_groups_ids= $fields_value['groupBox'];
            $fields_value['hideprice'] = $hidepriceBlock->hideprice;
            $fields_value['hideofferedprice'] = $hidepriceBlock->hideofferedprice;
            $fields_value['hidecart'] = $hidepriceBlock->hidecart;
            $fields_value['text_color'] = $hidepriceBlock->text_color;
            $fields_value['text_bg_color'] = $hidepriceBlock->text_bg_color;
            $fields_value['message'] = $hidepriceBlock->message;

            if (!$hidepriceBlock->Supplier) {
                $fields_value['Supplier[]']  = '';
            }
            else {
                $fields_value['Supplier[]']  = explode(",",$hidepriceBlock->Supplier);
            }
            if (!$hidepriceBlock->Manufacturer) {
                $fields_value['Manufacturer[]']  = '';
            }
            else {
                $fields_value['Manufacturer[]']  = explode(",",$hidepriceBlock->Manufacturer);
            }

            $fields_value['group_active'] = $hidepriceBlock->group_active;
            $fields_value['product_active'] = $hidepriceBlock->product_active;
            $fields_value['category_active'] = $hidepriceBlock->category_active;
            $fields_value['manufacturer_active'] = $hidepriceBlock->manufacturer_active;
            $fields_value['supplier_active'] = $hidepriceBlock->supplier_active;

        } else {
            $fields_value['id_addifyrequestaquote'] = Tools::getValue('id_addifyrequestaquote');
            $fields_value['active'] = (int)Tools::getValue('active');
            $fields_value['priority'] = Tools::getValue('priority');
            $fields_value['title'] = Tools::getValue('title');
            $fields_value['hideprice'] = Tools::getValue('hideprice');
            $fields_value['hideofferedprice'] = Tools::getValue('hideofferedprice');
            $fields_value['hidecart'] = Tools::getValue('hidecart');
            $fields_value['text_color'] = Tools::getValue('text_color');
            $fields_value['text_bg_color'] = Tools::getValue('text_bg_color');
            $fields_value['message'] = Tools::getValue('message');

            $fields_value['group_active']   = Tools::getValue('group_active');
            $fields_value['product_active']   = Tools::getValue('product_active');
            $fields_value['category_active']   = Tools::getValue('category_active');
            $fields_value['manufacturer_active']   = Tools::getValue('manufacturer_active');
            $fields_value['supplier_active']   = Tools::getValue('supplier_active');

            if (!Tools::getValue('groupBox')) {
                $fields_value['groupBox'] =  Tools::getValue('groupBox');
            } else {
                $fields_value['groupBox'] = implode(',', Tools::getValue('groupBox'));
            }
            $fields_value['type'] = Tools::getValue('type');
            if ($fields_value['type'] == 1) {
                $fields_value['product'] = '';
            } else {
                if (!Tools::getValue('product')) {
                    $fields_value['product'] = Tools::getValue('product');
                } else {
                    $fields_value['product'] = implode(',', Tools::getValue('product'));
                }
            }
            if ($fields_value['type']==2) {
                $fields_value['category'] = '';
            } else {
                if (Tools::getValue('category')) {
                    $fields_value['category'] = implode(',', Tools::getValue('category'));
                } else {
                    $fields_value['category'] ='' ;
                }
            }

            if (!Tools::getValue('Supplier')) {
                $fields_value['Supplier[]']  = Tools::getValue('Supplier[]');
            }
            else {
                $fields_value['Supplier']  = implode(",",Tools::getValue('Supplier'));
            }

            if (!Tools::getValue('Manufacturer')) {
                $fields_value['Manufacturer[]']  = Tools::getValue('Manufacturer[]');
            }
            else {
                $fields_value['Manufacturer']  = implode(",",Tools::getValue('Manufacturer'));
            }

            $accessed_groups_ids = Tools::getValue('groupBox');
        }

        if (!is_array($accessed_groups_ids)) {
            $accessed_groups_ids = array();
        }
        // Added values of object Group
        $groups = Group::getGroups($this->context->language->id);
        if (empty($accessed_groups_ids)) {
            $preselected = array(Configuration::get('PS_UNIDENTIFIED_GROUP'), Configuration::get('PS_GUEST_GROUP'), Configuration::get('PS_CUSTOMER_GROUP'));
            $accessed_groups_ids = array_merge($accessed_groups_ids, $preselected);
        }
        foreach ($groups as $group) {
            $fields_value['groupBox_'.$group['id_group']] = (isset($accessed_groups_ids) && $accessed_groups_ids)? Tools::getValue('groupBox_'.$group['id_group'], (in_array($group['id_group'], $accessed_groups_ids))) : true;
        }
        return $fields_value;
    }
    /**
     * Save form data.
     */
    protected function processSave()
    {
        $call_back = 'add';
        $form_values = $this->getConfigFormValues();

        if (!isset($form_values) && !$form_values) {
            return $this->context->controller->errors[] = $this->l('Empty post values.');
        }
        if (!is_numeric($form_values['priority'])) {
            $this->context->controller->errors[] = $this->l('Priority value is not valid .');
        }


        if (count($this->context->controller->errors)) {
            return $this->context->controller->errors;
        }

        if (($id_addifyrequestaquote = Tools::getValue('id_addifyrequestaquote'))) {
            $call_back = 'update';
            $hideprice = new AddifyrequestaquoteClass((int)$id_addifyrequestaquote);
        } else {
            $hideprice = new AddifyrequestaquoteClass();
        }
        $hideprice->title = $form_values['title'];
        $hideprice->active = $form_values['active'];
        $hideprice->groups = $form_values['groupBox'];
        $hideprice->product_type = $form_values['type'];
        $hideprice->product = $form_values['product'];
        $hideprice->categories = $form_values['category'];       
        $hideprice->priority = $form_values['priority'];
        $hideprice->hideprice = $form_values['hideprice'];
        $hideprice->hideofferedprice = $form_values['hideofferedprice']; 
        $hideprice->hidecart = $form_values['hidecart'];
        if($form_values['text_color']==null)
            $form_values['text_color']='#4285f4';
        $hideprice->text_color = $form_values['text_color'];
        if($form_values['text_bg_color']==null)
            $form_values['text_bg_color']='#515356';
        $hideprice->text_bg_color = $form_values['text_bg_color'];
        if($form_values['message']==null)
            $form_values['message']='Add to Quote';
        $hideprice->message = $form_values['message'];

        $hideprice->Supplier     = $form_values['Supplier'];
        $hideprice->Manufacturer     = $form_values['Manufacturer'];
        $hideprice->group_active     = $form_values['group_active'];
        $hideprice->product_active     = $form_values['product_active'];
        $hideprice->category_active     = $form_values['category_active'];
        $hideprice->manufacturer_active     = $form_values['manufacturer_active'];
        $hideprice->supplier_active     = $form_values['supplier_active'];

        if (!call_user_func(array($hideprice, $call_back))) {
            $this->context->controller->errors = sprintf($this->l('Something went wrong while performing operation %s'), $call_back);
        } else {
            // clear cache after add/update
            $this->flushCache();
            if($call_back=='add') {
                Tools::redirectAdmin($this->context->link->getAdminLink('AdminModules', true) . '&conf=3&configure=' . $this->name . '&tab_module=' . $this->tab . '&module_name=' . $this->name.'&rulesaddifyrequestaquote');
            } else {
                Tools::redirectAdmin($this->context->link->getAdminLink('AdminModules', true) . '&conf=4&configure=' . $this->name . '&tab_module=' . $this->tab . '&module_name=' . $this->name.'&rulesaddifyrequestaquote');
            }
        }
    }
    public function flushCache()
    {
        Tools::clearSmartyCache();
        Tools::clearXMLCache();
        Media::clearCache();
        Tools::generateIndex();
        if (true === Tools::version_compare(_PS_VERSION_, '1.7.0.0', '>=') &&
            is_callable(array('Tools', 'clearAllCache'))) {
            Tools::clearAllCache();
        }
    }
    /**
     * Save form data.
     */
    protected function postProcess()
    {
        if (Tools::isSubmit('submitAddifyrequestaquote')) {
            $this->processSave(); // save Rules tab data
        } 
        elseif (Tools::isSubmit('Submitcustomfields'.$this->name)) {
            $this->processCustomFieldsSave(); // save Custom Field tab data
        } elseif (Tools::isSubmit('status'.$this->name)) {
            if (!AddifyrequestaquoteClass::setStatus('active', (int)Tools::getValue('id_addifyrequestaquote'))) {
                $this->context->controller->errors[] = $this->l('Status update failed.');
            } else {
                Tools::redirectAdmin($this->context->link->getAdminLink('AdminModules', true) . '&conf=5&configure=' . $this->name . '&tab_module=' . $this->tab . '&module_name=' . $this->name.'&rulesaddifyrequestaquote');
            }
        } elseif (Tools::isSubmit('delete'.$this->name)) {
            if (!Validate::isLoadedObject($hideprice = new AddifyrequestaquoteClass((int)Tools::getValue('id_addifyrequestaquote')))) {
                $this->context->controller->errors[] = $this->l('Object not found.');
            } else {
                if (!$hideprice->delete()) {
                    $this->context->controller->errors[] = $this->l('Rule cannot be deleted.');
                } else {
                    $this->context->controller->confirmations[] = $this->l('Rule deleted successfully.');
                }
            }
        } elseif (Tools::isSubmit('submitBulkdelete'.$this->name)) {

            $addifyextendedhidepriceBox = Tools::getValue('addifyrequestaquoteBox');
            if (isset($addifyextendedhidepriceBox) && $addifyextendedhidepriceBox) {
                $deleted = 0;
                foreach ($addifyextendedhidepriceBox as $id_addifyrequestaquote) {
                    if (!Validate::isLoadedObject($hideprice = new AddifyrequestaquoteClass((int)$id_addifyrequestaquote))) {
                        $this->context->controller->errors[] = $this->l('Object not found.');
                        break;
                    } else {
                        if ($hideprice->delete()) {
                            $deleted++;
                        }
                    }
                }
                if (count($this->context->controller->errors)) {
                    $this->context->controller->errors;
                } else {
                    $this->context->controller->confirmations[] = sprintf($this->l('%s records deleted successfully.'), $deleted);
                }
            }
        } elseif (Tools::isSubmit('deleteaddifyrequestsall')) {
            if (!Validate::isLoadedObject($hideprice = new AddifyrequestsallClass((int)Tools::getValue('id_addifyrequestaquote')))) {
                $this->context->controller->errors[] = $this->l('Object not found.');
            } else {
                if (!$hideprice->delete()) {
                    $this->context->controller->errors[] = $this->l('Rule cannot be deleted.');
                } else {
                    $this->context->controller->confirmations[] = $this->l('Rule deleted successfully.');
                }
            }
        } elseif (Tools::isSubmit('submitBulkdeleteaddifyrequestsall')) {
            $addifyextendedhidepriceBox = Tools::getValue('addifyrequestsallBox');
            if (isset($addifyextendedhidepriceBox) && $addifyextendedhidepriceBox) {
                $deleted = 0;
                foreach ($addifyextendedhidepriceBox as $id_addifyrequestaquote) {
                    if (!Validate::isLoadedObject($hideprice = new AddifyrequestsallClass((int)$id_addifyrequestaquote))) {
                        $this->context->controller->errors[] = $this->l('Object not found.');
                        break;
                    } else {
                        if ($hideprice->delete()) {
                            $deleted++;
                        }
                    }
                }
                if (count($this->context->controller->errors)) {
                    $this->context->controller->errors;
                } else {
                    $this->context->controller->confirmations[] = sprintf($this->l('%s records deleted successfully.'), $deleted);
                }
            }
        }

    }

    protected function renderconfigForm()
    {
        $fields_form = array(
            'form' => array(
                'legend' => array(
                    'title' => $this->l('General Settings'),
                    'icon' => 'icon-cogs'
                ),
           
                'input' => array(

                        array(
                            'type' => 'switch',
                            'label' => $this->l('Module'),
                            'name' => 'addifyraq_enable',
                            'desc' => $this->l('Enable/Disable quotation system'),
                            'values' => array(
                                array(
                                    'id' => 'active_on',
                                    'value' => true,
                                    'label' => $this->l('Enabled')
                                ),
                                array(
                                    'id' => 'active_off',
                                    'value' => false,
                                    'label' => $this->l('Disabled')
                                )

                            ),
                        ),

                        array(
                            'type' => 'switch',
                            'label' => $this->l('Catalog Mode For Whole Store'),
                            'name' => 'addifyraq_catalogmode_enable',
                            'desc' => $this->l('Enable to display Add To Quote button on all products'),
                            'values' => array(
                                array(
                                    'id' => 'active_on',
                                    'value' => true,
                                    'label' => $this->l('Enabled')
                                ),
                                array(
                                    'id' => 'active_off',
                                    'value' => false,
                                    'label' => $this->l('Disabled')
                                )

                            ),
                        ),

                        array(
                            'type' => 'switch',
                            'label' => $this->l('Hide Add To Cart Button'),
                            'desc' => $this->l('Enable to hide price of all products'),
                            'name' => 'addifyraq_hidecart',
                            'values' => array(
                                array(
                                    'id' => 'active_on',
                                    'value' => 1,
                                    'label' => $this->l('Enabled')
                                ),
                                array(
                                    'id' => 'active_off',
                                    'value' => 0,
                                    'label' => $this->l('Disabled')
                                )
                            ),
                        ),

                        array(
                            'type' => 'switch',
                            'label' => $this->l('Hide Price '),
                            'name' => 'addifyraq_hideprice',
                            'desc' => $this->l('Enable to hide Add to Cart button on all products'),
                            'values' => array(
                                array(
                                    'id' => 'active_on',
                                    'value' => 1,
                                    'label' => $this->l('Enabled')
                                ),
                                array(
                                    'id' => 'active_off',
                                    'value' => 0,
                                    'label' => $this->l('Disabled')
                                )
                            ),
                        ),
                        array(
                            'type' => 'switch',
                            'label' => $this->l('Hide Add To Quote button on Listing/Homepage'),
                            'desc' => $this->l('Enable/Disable hide add to quote button on Listing/Homepage.'),
                            'name' => 'addifyraq_hidequote',
                            'values' => array(
                                array(
                                    'id' => 'active_on',
                                    'value' => 1,
                                    'label' => $this->l('Enabled')
                                ),
                                array(
                                    'id' => 'active_off',
                                    'value' => 0,
                                    'label' => $this->l('Disabled')
                                )
                            ),
                        ),

                        array(
                            'type'          => 'color',
                            'label'         => $this->l('Quote Button Text Color'),
                            'name'          => 'addifyraq_text_color',
                        ),
                        array(
                            'type'          => 'color',
                            'label'         => $this->l('Quote Button Background Color'),
                            'name'          => 'addifyraq_text_bg_color',
                        ),
                        array(
                            'type' => 'text',
                            'label' => $this->l('Quote Button Text'),
                            'name' => 'addifyraq_message',
                        ),

                        

                        array(
                            'type' => 'switch',
                            'label' => $this->l('Email Notification For New Quote'),
                            'desc' => $this->l('Enable/Disable option for admin to enter email where quotation will also be sent.'),
                            'name' => 'aadifyraq_semail_enable',
                            'values' => array(
                                array(
                                    'id' => 'active_on',
                                    'value' => 1,
                                    'label' => $this->l('Enabled')
                                ),
                                array(
                                    'id' => 'active_off',
                                    'value' => 0,
                                    'label' => $this->l('Disabled')
                                )
                            ),
                        ),

                        array(
                            'type'          => 'text',
                            'label'         => $this->l('Shop/Manager Email'),
                            'name'          => 'aadifyraq_semail',
                            'desc' => $this->l('Get copy of quotation when submitted.'),
                        ),

                        array(
                            'type' => 'switch',
                            'label' => $this->l('Email Notification For New Message'),
                            'desc' => $this->l('Enable to send an email to admin whenever a user sends a message in quotes'),
                            'name' => 'addifyraq_enable_message_notify',
                            'values' => array(
                                array(
                                    'id' => 'active_on',
                                    'value' => 1,
                                    'label' => $this->l('Enabled')
                                ),
                                array(
                                    'id' => 'active_off',
                                    'value' => 0,
                                    'label' => $this->l('Disabled')
                                )
                            ),
                        ),
                    
                        array(
                            'type' => 'switch',
                            'label' => $this->l('Show Add To Quote Button on Out of Stock Products'),
                            'desc' => $this->l('Enable/Disable show add to quote button on Out of Stock Products.'),
                            'name' => 'addifyraq_enable_outofstock',
                            'values' => array(
                                array(
                                    'id' => 'active_on',
                                    'value' => 1,
                                    'label' => $this->l('Enabled')
                                ),
                                array(
                                    'id' => 'active_off',
                                    'value' => 0,
                                    'label' => $this->l('Disabled')
                                )
                            ),
                        ),

                        array(
                            'type' => 'switch',
                            'label' => $this->l('Show Offered Price'),
                            'name' => 'addifyraq_offered',
                            'desc' => $this->l('Add feature to enter offered price of product in quote.'),
                            'values' => array(
                                array(
                                    'id' => 'active_on',
                                    'value' => true,
                                    'label' => $this->l('Enabled')
                                ),
                                array(
                                    'id' => 'active_off',
                                    'value' => false,
                                    'label' => $this->l('Disabled')
                                )
                            ),
                        ),
                    ),
                'submit' => array(
                    'title' => $this->l('Save'),
                ),
            )
        );

        $helper = new HelperForm();
        $helper->show_toolbar = false;
        $helper->module = $this;
        $lang = new Language((int)Configuration::get('PS_LANG_DEFAULT'));
        $helper->default_form_language = $lang->id;
        $helper->allow_employee_form_lang = Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG') ? Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG') : 0;
        $helper->identifier = $this->identifier;
        $helper->submit_action = 'Submitconfig'.$this->name;
        $helper->currentIndex = $this->context->link->getAdminLink('AdminModules', false).'&configure='.$this->name.'&tab_module='.$this->tab.'&module_name='.$this->name;
        $helper->token = Tools::getAdminTokenLite('AdminModules');
        $helper->tpl_vars = array(
            'fields_value' => $this->getRenderConfigFormValues(),
            'languages' => $this->context->controller->getLanguages(),
            'id_language' => $this->context->language->id,
            'context_link' => Context::getContext()->link,
        );
       return $helper->generateForm(array($fields_form));
    }

    protected function getRenderConfigFormValues()
    {
        $fields_value = array();

        if((Tools::isSubmit('Submitconfig'.$this->name) === false))
        {

             $fields_value['addifyraq_enable'] = Configuration::get('ADDIFYREQUESTAQUOTE_LIVE_MODE');
             $fields_value['addifyraq_offered'] = Configuration::get('ADDIFYREQUESTAQUOTE_OFFERED_MODE');
             $fields_value['aadifyraq_semail'] = Configuration::get('ADDIFYREQUESTAQUOTE_SEMAIL');

            $fields_value['addifyraq_catalogmode_enable'] = Configuration::get('ADDIFYREQUESTAQUOTE_CATALOGMODE_ENABLE');
            $fields_value['addifyraq_hideprice'] = Configuration::get('ADDIFYREQUESTAQUOTE_HIDEPRICE');
            $fields_value['addifyraq_hidecart'] = Configuration::get('ADDIFYREQUESTAQUOTE_HIDECART');
            $fields_value['addifyraq_hidequote'] = Configuration::get('ADDIFYREQUESTAQUOTE_HIDEQUOTE');
            $fields_value['addifyraq_message'] = Configuration::get('ADDIFYREQUESTAQUOTE_MESSAGE');
            $fields_value['addifyraq_text_color'] = Configuration::get('ADDIFYREQUESTAQUOTE_TEXT_COLOR');
            $fields_value['addifyraq_text_bg_color'] = Configuration::get('ADDIFYREQUESTAQUOTE_TEXT_BG_COLOR');
            $fields_value['aadifyraq_semail_enable'] = Configuration::get('ADDIFYREQUESTAQUOTE_SEMAIL_ENABLE');
            $fields_value['addifyraq_enable_message_notify'] = Configuration::get('ADDIFYREQUESTAQUOTE_ENABLE_MESSAGE_NOTIFY');
            $fields_value['addifyraq_enable_outofstock'] = Configuration::get('ADDIFYREQUESTAQUOTE_ENABLE_OUTOFSTOCK');
        }
        else
        {
            $fields_value['ADDIFYREQUESTAQUOTE_LIVE_MODE'] = Tools::getValue('addifyraq_enable');
            $fields_value['ADDIFYREQUESTAQUOTE_OFFERED_MODE'] = Tools::getValue('addifyraq_offered');
            $fields_value['ADDIFYREQUESTAQUOTE_SEMAIL'] = Tools::getValue('aadifyraq_semail');

            $fields_value[' ADDIFYREQUESTAQUOTE_CATALOGMODE_ENABLE'] = Tools::getValue('addifyraq_catalogmode_enable');
            $fields_value[' ADDIFYREQUESTAQUOTE_HIDEPRICE '] = Tools::getValue('addifyraq_hideprice ');
            $fields_value[' ADDIFYREQUESTAQUOTE_HIDECART'] = Tools::getValue('addifyraq_hidecart');
            $fields_value[' ADDIFYREQUESTAQUOTE_MESSAGE '] = Tools::getValue('addifyraq_message ');
            $fields_value[' ADDIFYREQUESTAQUOTE_TEXT_COLOR '] = Tools::getValue('addifyraq_text_color ');
            $fields_value[' ADDIFYREQUESTAQUOTE_TEXT_BG_COLOR '] = Tools::getValue('addifyraq_text_bg_color ');
            $fields_value[' ADDIFYREQUESTAQUOTE_HIDEQUOTE '] = Tools::getValue('addifyraq_hidequote ');
            $fields_value[' ADDIFYREQUESTAQUOTE_SEMAIL_ENABLE '] = Tools::getValue('aadifyraq_semail_enable ');
            $fields_value[' ADDIFYREQUESTAQUOTE_ENABLE_MESSAGE_NOTIFY '] = Tools::getValue('addifyraq_enable_message_notify ');
            $fields_value[' ADDIFYREQUESTAQUOTE_ENABLE_OUTOFSTOCK '] = Tools::getValue('addifyraq_enable_outofstock ');

        }   

        return $fields_value;
    }

    protected function processconfigSave()
    {   
        $form_values = $this->getRenderConfigFormValues();

        if (Tools::getValue('aadifyraq_semail') && !validate::isEmail(Tools::getValue('aadifyraq_semail'))) {
            $this->context->controller->errors[] = $this->l('Shop/Manager Email is not valid .');
        }

        if (count($this->context->controller->errors)) {
            return $this->context->controller->errors;
        }

        Configuration::updateValue('ADDIFYREQUESTAQUOTE_LIVE_MODE', Tools::getValue('addifyraq_enable'));
        Configuration::updateValue('ADDIFYREQUESTAQUOTE_OFFERED_MODE', Tools::getValue('addifyraq_offered'));
        Configuration::updateValue('ADDIFYREQUESTAQUOTE_SEMAIL', Tools::getValue('aadifyraq_semail'));

        Configuration::updateValue('ADDIFYREQUESTAQUOTE_CATALOGMODE_ENABLE', Tools::getValue('addifyraq_catalogmode_enable'));
        Configuration::updateValue('ADDIFYREQUESTAQUOTE_HIDEPRICE', Tools::getValue('addifyraq_hideprice'));
        Configuration::updateValue('ADDIFYREQUESTAQUOTE_HIDECART', Tools::getValue('addifyraq_hidecart'));
        Configuration::updateValue('ADDIFYREQUESTAQUOTE_MESSAGE', Tools::getValue('addifyraq_message'));
        Configuration::updateValue('ADDIFYREQUESTAQUOTE_TEXT_COLOR', Tools::getValue('addifyraq_text_color'));
        Configuration::updateValue('ADDIFYREQUESTAQUOTE_TEXT_BG_COLOR', Tools::getValue('addifyraq_text_bg_color'));
        Configuration::updateValue('ADDIFYREQUESTAQUOTE_HIDEQUOTE', Tools::getValue('addifyraq_hidequote'));
        Configuration::updateValue('ADDIFYREQUESTAQUOTE_SEMAIL_ENABLE', Tools::getValue('aadifyraq_semail_enable'));
        Configuration::updateValue('ADDIFYREQUESTAQUOTE_ENABLE_MESSAGE_NOTIFY', Tools::getValue('addifyraq_enable_message_notify'));
        Configuration::updateValue('ADDIFYREQUESTAQUOTE_ENABLE_OUTOFSTOCK', Tools::getValue('addifyraq_enable_outofstock'));


        if (Tools::getValue('addifyraq_catalogmode_enable') == 0) {
            Configuration::updateValue('ADDIFYREQUESTAQUOTE_HIDEPRICE', 0);
            Configuration::updateValue('ADDIFYREQUESTAQUOTE_HIDECART', 0);
            Configuration::updateValue('ADDIFYREQUESTAQUOTE_HIDEQUOTE', 0);
        }

        $this->flushCache();

        Tools::redirectAdmin($this->context->link->getAdminLink('AdminModules', true) . '&conf=6&configure=' . $this->name . '&tab_module=' . $this->tab . '&module_name=' . $this->name);
    }

    protected function renderPredefinedConfigForm()
    {
        $fields_form = array(
            'form' => array(
                'legend' => array(
                    'title' => $this->l('Predefined Fields'),
                    'icon' => 'icon-cogs'
                ),
           
                'input' => array(
                      
                        array( // company field
                            'type' => 'switch',
                            'label' => $this->l('Company Name Field'),
                            'name' => 'aadifyraq_companyname_active',
                            'desc' => $this->l('Enable to display company name field on quotation form'),
                            'values' => array(
                                array(
                                    'id' => 'active_on',
                                    'value' => true,
                                    'label' => $this->l('Enabled')
                                ),
                                array(
                                    'id' => 'active_off',
                                    'value' => false,
                                    'label' => $this->l('Disabled')
                                )
                           ),
                        ),
                        array(
                            'type' => 'switch',
                            'label' => $this->l('Company Name Mandatory'),
                            'name' => 'aadifyraq_companyname_mandatory',
                            'desc' => $this->l('Enable to make company name field mandatory on quotation form'),
                            'values' => array(
                                array(
                                    'id' => 'active_on',
                                    'value' => true,
                                    'label' => $this->l('Enabled')
                                ),
                                array(
                                    'id' => 'active_off',
                                    'value' => false,
                                    'label' => $this->l('Disabled')
                                )
                           ),
                        ),
                        array(
                            'type'          => 'text',
                            'label'         => $this->l('Company Name Field Label'),
                            'name'          => 'aadifyraq_companyname_lable',
                            'desc' => $this->l('Enter label that will appear with company name field on quoation form'),
                        ),
                        
                        
                        array( // website field
                            'type' => 'switch',
                            'label' => $this->l('Website Field'),
                            'name' => 'aadifyraq_website_active',
                            'desc' => $this->l('Enable to display website field on quotation form '),
                            'values' => array(
                                array(
                                    'id' => 'active_on',
                                    'value' => true,
                                    'label' => $this->l('Enabled')
                                ),
                                array(
                                    'id' => 'active_off',
                                    'value' => false,
                                    'label' => $this->l('Disabled')
                                )
                           ),
                        ),
                        array(
                            'type' => 'switch',
                            'label' => $this->l('Website Mandatory'),
                            'name' => 'aadifyraq_website_mandatory',
                            'desc' => $this->l('Enable to make website field mandatory on quotation form'),
                            'values' => array(
                                array(
                                    'id' => 'active_on',
                                    'value' => true,
                                    'label' => $this->l('Enabled')
                                ),
                                array(
                                    'id' => 'active_off',
                                    'value' => false,
                                    'label' => $this->l('Disabled')
                                )
                           ),
                        ),
                        array(
                            'type'          => 'text',
                            'label'         => $this->l('Website Field Label'),
                            'name'          => 'aadifyraq_website_lable',
                            'desc' => $this->l('Enable label that will appear with website field on quotation form'),
                        ),
                        

                        array( // phone no field
                            'type' => 'switch',
                            'label' => $this->l('Phone Field'),
                            'name' => 'aadifyraq_phone_active',
                            'desc' => $this->l('Enable to display phone field on quotation form'),
                            'values' => array(
                                array(
                                    'id' => 'active_on',
                                    'value' => true,
                                    'label' => $this->l('Enabled')
                                ),
                                array(
                                    'id' => 'active_off',
                                    'value' => false,
                                    'label' => $this->l('Disabled')
                                )
                           ),
                        ),
                        array(
                            'type' => 'switch',
                            'label' => $this->l('Phone Mandatory'),
                            'desc' => $this->l('Enable to make phone field mandatory on quotation form'),
                            'name' => 'aadifyraq_phone_mandatory',
                            'values' => array(
                                array(
                                    'id' => 'active_on',
                                    'value' => true,
                                    'label' => $this->l('Enabled')
                                ),
                                array(
                                    'id' => 'active_off',
                                    'value' => false,
                                    'label' => $this->l('Disabled')
                                )
                           ),
                        ),
                        array(
                            'type'          => 'text',
                            'label'         => $this->l('Phone Field Label'),
                            'desc' => $this->l('Enter label that will appear with phone field on quotation form'),
                            'name'          => 'aadifyraq_phone_lable',
                        ),
                        array( // VAT number field
                            'type' => 'switch',
                            'label' => $this->l('VAT Number Field'),
                            'name' => 'aadifyraq_vatnumber_active',
                            'desc' => $this->l('Enable to display VAT number field on quotation form'),
                            'values' => array(
                                array(
                                    'id' => 'active_on',
                                    'value' => true,
                                    'label' => $this->l('Enabled')
                                ),
                                array(
                                    'id' => 'active_off',
                                    'value' => false,
                                    'label' => $this->l('Disabled')
                                )
                           ),
                        ),
                        array(
                            'type' => 'switch',
                            'label' => $this->l('VAT Number Mandatory'),
                            'desc' => $this->l('Enable to make VAT number field mandatory on quotation form'),
                            'name' => 'aadifyraq_vatnumber_mandatory',
                            'values' => array(
                                array(
                                    'id' => 'active_on',
                                    'value' => true,
                                    'label' => $this->l('Enabled')
                                ),
                                array(
                                    'id' => 'active_off',
                                    'value' => false,
                                    'label' => $this->l('Disabled')
                                )
                           ),
                        ),
                        array(
                            'type'          => 'text',
                            'label'         => $this->l('VAT Number Field Label'),
                            'name'          => 'aadifyraq_vatnumber_lable',
                            'desc' => $this->l('Enter label that will appear with VAT number field on quotation form'),
                        ),
                        array( // file upload field
                            'type' => 'switch',
                            'label' => $this->l('File Upload'),
                            'name' => 'aadifyraq_fileupload_active',
                            'desc' => $this->l('Enable to display upload field on quotation form'),
                            'values' => array(
                                array(
                                    'id' => 'active_on',
                                    'value' => true,
                                    'label' => $this->l('Enabled')
                                ),
                                array(
                                    'id' => 'active_off',
                                    'value' => false,
                                    'label' => $this->l('Disabled')
                                )
                           ),
                        ),
                        array(
                            'type' => 'switch',
                            'label' => $this->l('File Upload Mandatory'),
                            'name' => 'aadifyraq_fileupload_mandatory',
                            'desc' => $this->l('Enable to make upload field mandatory on quation form'),
                            'values' => array(
                                array(
                                    'id' => 'active_on',
                                    'value' => true,
                                    'label' => $this->l('Enabled')
                                ),
                                array(
                                    'id' => 'active_off',
                                    'value' => false,
                                    'label' => $this->l('Disabled')
                                )
                           ),
                        ),
                         array(
                            'type'          => 'text',
                            'label'         => $this->l('File Upload Label'),
                            'name'          => 'aadifyraq_fileupload_lable',
                            'desc' => $this->l('Enter label that will appear with file uplaod field on quoation form'),
                        ),
                        array(
                            'type' => 'switch',
                            'label' => $this->l('Text type'),
                            'name' => 'aadifyraq_texttype_active',
                            'desc' => $this->l('Enable to display text field on quotation form'),
                            'values' => array(
                                array(
                                    'id' => 'active_on',
                                    'value' => true,
                                    'label' => $this->l('Enabled')
                                ),
                                array(
                                    'id' => 'active_off',
                                    'value' => false,
                                    'label' => $this->l('Disabled')
                                )
                           ),
                        ),
                        array(
                            'type' => 'switch',
                            'label' => $this->l('Text type Mandatory'),
                            'name' => 'aadifyraq_texttype_mandatory',
                            'desc' => $this->l('Enable to make text field mandatory on quation form'),
                            'values' => array(
                                array(
                                    'id' => 'active_on',
                                    'value' => true,
                                    'label' => $this->l('Enabled')
                                ),
                                array(
                                    'id' => 'active_off',
                                    'value' => false,
                                    'label' => $this->l('Disabled')
                                )
                           ),
                        ),
                        array(
                            'type'          => 'text',
                            'label'         => $this->l('Text type Label'),
                            'name'          => 'aadifyraq_texttype_lable',
                            'desc' => $this->l('Enter label that will appear with text field on quoation form'),
                        ),
                        array(
                            'type'          => 'text',
                            'label'         => $this->l('Text Type Place Holder'),
                            'name'          => 'aadifyraq_texttype_placeholder',
                            'desc' => $this->l('Set custom palce holder for text field'),
                        ),
                        array(
                            'type' => 'switch',
                            'label' => $this->l('Dropdown Field'),
                            'name' => 'aadifyraq_dropdown_active',
                            'desc' => $this->l('Enable to display dropdown field on quotation form'),
                            'values' => array(
                                array(
                                    'id' => 'active_on',
                                    'value' => true,
                                    'label' => $this->l('Enabled')
                                ),
                                array(
                                    'id' => 'active_off',
                                    'value' => false,
                                    'label' => $this->l('Disabled')
                                )
                           ),
                        ),
                        array(
                            'type'          => 'text',
                            'label'         => $this->l('Dropdown Field Label'),
                            'name'          => 'aadifyraq_dropdown_labe',
                            'desc' => $this->l('Enter label that will appear with dropdown field on quoation form'),
                        ),
                        array(
                            'type'          => 'text',
                            'label'         => $this->l('Dropdown Field Options'),
                            'name'          => 'aadifyraq_dropdown_options',
                            'placeholder'   => $this->l('option1,option2,option3'),
                            'desc' => $this->l('Enter comma separated options for dropdown field'),
                        ),
                        
                        
                        // array(
                        // 'type' => 'switch',
                        // 'label' => $this->l('Dropdown Mandatory'),
                        // 'name' => 'aadifyraq_dropdown_mandatory',
                        // 'values' => array(
                        //     array(
                        //         'id' => 'active_on',
                        //         'value' => true,
                        //         'label' => $this->l('Enabled')
                        //     ),
                        //     array(
                        //         'id' => 'active_off',
                        //         'value' => false,
                        //         'label' => $this->l('Disabled')
                        //     )

                        //    ),
                        // ),
                        array(
                            'type' => 'switch',
                            'label' => $this->l('Checkbox Field'),
                            'name' => 'aadifyraq_multicheck_active',
                            'desc' => $this->l('Enable to display checkbox field on quotation form'),
                            'values' => array(
                                array(
                                    'id' => 'active_on',
                                    'value' => true,
                                    'label' => $this->l('Enabled')
                                ),
                                array(
                                    'id' => 'active_off',
                                    'value' => false,
                                    'label' => $this->l('Disabled')
                                )
                           ),
                        ),
                        array(
                        'type' => 'switch',
                        'label' => $this->l('Checkbox Mandatory'),
                        'name' => 'aadifyraq_multiselect_mandatory',
                        'desc' => $this->l('Enable to make Checkbox field mandatory on quation form'),
                        
                        'values' => array(
                            array(
                                'id' => 'active_on',
                                'value' => true,
                                'label' => $this->l('Enabled')
                            ),
                            array(
                                'id' => 'active_off',
                                'value' => false,
                                'label' => $this->l('Disabled')
                            )

                           ),
                        ),   
                        array(
                            'type'          => 'text',
                            'label'         => $this->l('Checkbox Field Label'),
                            'name'          => 'aadifyraq_multicheck_lable',
                            'desc' => $this->l('Enter label that will appear with checkbox field on quoation form'),
                        ),
                        array(
                            'type'          => 'text',
                            'label'         => $this->l('Checkbox Field Options'),
                            'name'          => 'aadifyraq_multicheck_options',
                            'placeholder'   => $this->l('option1,option2,option3'),
                            'desc' => $this->l('Enter comma separated options for checkbox field'),
                        ),
                        
                    ),
                'submit' => array(
                    'title' => $this->l('Save'),
                ),
            )
        );

        $helper = new HelperForm();
        $helper->show_toolbar = false;
        $helper->module = $this;
        $lang = new Language((int)Configuration::get('PS_LANG_DEFAULT'));
        $helper->default_form_language = $lang->id;
        $helper->allow_employee_form_lang = Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG') ? Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG') : 0;
        $helper->identifier = $this->identifier;
        $helper->submit_action = 'Submitpredefinedconfig'.$this->name;
        $helper->currentIndex = $this->context->link->getAdminLink('AdminModules', false).'&configure='.$this->name.'&tab_module='.$this->tab.'&module_name='.$this->name.'&predefinedaddifyrequestaquote';
        $helper->token = Tools::getAdminTokenLite('AdminModules');
        $helper->tpl_vars = array(
            'fields_value' => $this->getRenderPredefinedConfigFormValues(),
            'languages' => $this->context->controller->getLanguages(),
            'id_language' => $this->context->language->id,
            'context_link' => Context::getContext()->link,
        );
       return $helper->generateForm(array($fields_form));
    }

    protected function getRenderPredefinedConfigFormValues()
    {
        $fields_value = array();

        if((Tools::isSubmit('Submitpredefinedconfig'.$this->name) === false))
        {

             $fields_value['aadifyraq_texttype_active'] = Configuration::get('ADDIFYREQUESTAQUOTE_TEXTTYPE_ACTIVE');
             $fields_value['aadifyraq_texttype_lable'] = Configuration::get('ADDIFYREQUESTAQUOTE_TEXTTYPE_LABLE');
             $fields_value['aadifyraq_texttype_placeholder'] = Configuration::get('ADDIFYREQUESTAQUOTE_TEXTTYPE_PLACEHOLDER');
             $fields_value['aadifyraq_fileupload_active'] = Configuration::get('ADDIFYREQUESTAQUOTE_FILEUPLOAD_ACTIVE');
             $fields_value['aadifyraq_fileupload_lable'] = Configuration::get('ADDIFYREQUESTAQUOTE_FILEUPLOAD_LABLE');
             $fields_value['aadifyraq_multicheck_active'] = Configuration::get('ADDIFYREQUESTAQUOTE_MULTICHECK_ACTIVE');
             $fields_value['aadifyraq_multicheck_lable'] = Configuration::get('ADDIFYREQUESTAQUOTE_MULTICHECK_LABLE');
             $fields_value['aadifyraq_multicheck_options'] = Configuration::get('ADDIFYREQUESTAQUOTE_MULTICHECK_OPTIONS');
             $fields_value['aadifyraq_dropdown_active'] = Configuration::get('ADDIFYREQUESTAQUOTE_DROPDOWN_ACTIVE');
             $fields_value['aadifyraq_dropdown_labe'] = Configuration::get('ADDIFYREQUESTAQUOTE_DROPDOWN_LABLE');
             $fields_value['aadifyraq_dropdown_options'] = Configuration::get('ADDIFYREQUESTAQUOTE_DROPDOWN_OPTIONS');

            $fields_value['aadifyraq_companyname_active'] = Configuration::get('ADDIFYREQUESTAQUOTE_COMPANYNAME_ACTIVE');
            $fields_value['aadifyraq_companyname_lable'] = Configuration::get('ADDIFYREQUESTAQUOTE_COMPANYNAME_LABLE');
            $fields_value['aadifyraq_companyname_mandatory'] = Configuration::get('ADDIFYREQUESTAQUOTE_COMPANYNAME_MANDATORY');
            $fields_value['aadifyraq_website_active'] = Configuration::get('ADDIFYREQUESTAQUOTE_WEBSITE_ACTIVE');
            $fields_value['aadifyraq_website_lable'] = Configuration::get('ADDIFYREQUESTAQUOTE_WEBSITE_LABLE');
            $fields_value['aadifyraq_website_mandatory'] = Configuration::get('ADDIFYREQUESTAQUOTE_WEBSITE_MANDATORY');
            $fields_value['aadifyraq_phone_active'] = Configuration::get('ADDIFYREQUESTAQUOTE_PHONE_ACTIVE');
            $fields_value['aadifyraq_phone_lable'] = Configuration::get('ADDIFYREQUESTAQUOTE_PHONE_LABLE');
            $fields_value['aadifyraq_phone_mandatory'] = Configuration::get('ADDIFYREQUESTAQUOTE_PHONE_MANDATORY');
            $fields_value['aadifyraq_vatnumber_active'] = Configuration::get('ADDIFYREQUESTAQUOTE_VATNUMBER_ACTIVE');
            $fields_value['aadifyraq_vatnumber_lable'] = Configuration::get('ADDIFYREQUESTAQUOTE_VATNUMBER_LABLE');
            $fields_value['aadifyraq_vatnumber_mandatory'] = Configuration::get('ADDIFYREQUESTAQUOTE_VATNUMBER_MANDATORY');
            $fields_value['aadifyraq_fileupload_mandatory'] = Configuration::get('ADDIFYREQUESTAQUOTE_FILEUPLOAD_MANDATORY');
            $fields_value['aadifyraq_texttype_mandatory'] = Configuration::get('ADDIFYREQUESTAQUOTE_TEXTTYPE_MANDATORY');
            $fields_value['aadifyraq_dropdown_mandatory'] = Configuration::get('ADDIFYREQUESTAQUOTE_DROPDOWN_MANDATORY');
            $fields_value['aadifyraq_multiselect_mandatory'] = Configuration::get('ADDIFYREQUESTAQUOTE_MULTISELECT_MANDATORY');

        }
        else
        {
            $fields_value['ADDIFYREQUESTAQUOTE_TEXTTYPE_ACTIVE'] = Tools::getValue('aadifyraq_texttype_active');
            $fields_value['ADDIFYREQUESTAQUOTE_TEXTTYPE_LABLE'] = Tools::getValue('aadifyraq_texttype_lable');
            $fields_value['ADDIFYREQUESTAQUOTE_TEXTTYPE_PLACEHOLDER'] = Tools::getValue('aadifyraq_texttype_placeholder');
            $fields_value['ADDIFYREQUESTAQUOTE_FILEUPLOAD_ACTIVE'] = Tools::getValue('aadifyraq_fileupload_active');
            $fields_value['ADDIFYREQUESTAQUOTE_FILEUPLOAD_LABLE'] = Tools::getValue('aadifyraq_fileupload_lable');
            $fields_value['ADDIFYREQUESTAQUOTE_MULTICHECK_ACTIVE'] = Tools::getValue('aadifyraq_multicheck_active');
            $fields_value['ADDIFYREQUESTAQUOTE_MULTICHECK_LABLE'] = Tools::getValue('aadifyraq_multicheck_lable');
            $fields_value['ADDIFYREQUESTAQUOTE_MULTICHECK_OPTIONS'] = Tools::getValue('aadifyraq_multicheck_options');
            $fields_value['ADDIFYREQUESTAQUOTE_DROPDOWN_ACTIVE'] = Tools::getValue('aadifyraq_dropdown_active');
            $fields_value['ADDIFYREQUESTAQUOTE_DROPDOWN_LABLE'] = Tools::getValue('aadifyraq_dropdown_labe');
            $fields_value['ADDIFYREQUESTAQUOTE_DROPDOWN_OPTIONS'] = Tools::getValue('aadifyraq_dropdown_options');

            $fields_value['ADDIFYREQUESTAQUOTE_COMPANYNAME_ACTIVE'] = Tools::getValue('aadifyraq_companyname_active');
            $fields_value['ADDIFYREQUESTAQUOTE_COMPANYNAME_LABLE'] = Tools::getValue('aadifyraq_companyname_lable');
            $fields_value['ADDIFYREQUESTAQUOTE_COMPANYNAME_MANDATORY'] = Tools::getValue('aadifyraq_companyname_mandatory');
            $fields_value['ADDIFYREQUESTAQUOTE_WEBSITE_ACTIVE'] = Tools::getValue('aadifyraq_website_active');
            $fields_value['ADDIFYREQUESTAQUOTE_WEBSITE_LABLE'] = Tools::getValue('aadifyraq_website_lable');
            $fields_value['ADDIFYREQUESTAQUOTE_WEBSITE_MANDATORY'] = Tools::getValue('aadifyraq_website_mandatory');
            $fields_value['ADDIFYREQUESTAQUOTE_PHONE_ACTIVE'] = Tools::getValue('aadifyraq_phone_active');
            $fields_value['ADDIFYREQUESTAQUOTE_PHONE_LABLE'] = Tools::getValue('aadifyraq_phone_lable');
            $fields_value['ADDIFYREQUESTAQUOTE_PHONE_MANDATORY'] = Tools::getValue('aadifyraq_phone_mandatory');
            $fields_value['ADDIFYREQUESTAQUOTE_VATNUMBER_ACTIVE'] = Tools::getValue('aadifyraq_vatnumber_active');
            $fields_value['ADDIFYREQUESTAQUOTE_VATNUMBER_LABLE'] = Tools::getValue('aadifyraq_vatnumber_lable');
            $fields_value['ADDIFYREQUESTAQUOTE_VATNUMBER_MANDATORY'] = Tools::getValue('aadifyraq_vatnumber_mandatory');
            $fields_value['ADDIFYREQUESTAQUOTE_FILEUPLOAD_MANDATORY'] = Tools::getValue('aadifyraq_fileupload_mandatory');
            $fields_value['ADDIFYREQUESTAQUOTE_TEXTTYPE_MANDATORY'] = Tools::getValue('aadifyraq_texttype_mandatory');
            $fields_value['ADDIFYREQUESTAQUOTE_DROPDOWN_MANDATORY'] = Tools::getValue('aadifyraq_dropdown_mandatory');
            $fields_value['ADDIFYREQUESTAQUOTE_MULTISELECT_MANDATORY'] = Tools::getValue('aadifyraq_multiselect_mandatory');

        }   

        return $fields_value;
    }

    protected function processPredefinedConfigSave()
    {   
        $form_values = $this->getRenderPredefinedConfigFormValues();

        Configuration::updateValue('ADDIFYREQUESTAQUOTE_TEXTTYPE_ACTIVE', Tools::getValue('aadifyraq_texttype_active'));
        Configuration::updateValue('ADDIFYREQUESTAQUOTE_TEXTTYPE_LABLE', Tools::getValue('aadifyraq_texttype_lable'));
        Configuration::updateValue('ADDIFYREQUESTAQUOTE_TEXTTYPE_PLACEHOLDER', Tools::getValue('aadifyraq_texttype_placeholder'));
        Configuration::updateValue('ADDIFYREQUESTAQUOTE_FILEUPLOAD_ACTIVE', Tools::getValue('aadifyraq_fileupload_active'));
        Configuration::updateValue('ADDIFYREQUESTAQUOTE_FILEUPLOAD_LABLE', Tools::getValue('aadifyraq_fileupload_lable'));
        Configuration::updateValue('ADDIFYREQUESTAQUOTE_MULTICHECK_ACTIVE', Tools::getValue('aadifyraq_multicheck_active'));
        Configuration::updateValue('ADDIFYREQUESTAQUOTE_MULTICHECK_LABLE', Tools::getValue('aadifyraq_multicheck_lable'));
        Configuration::updateValue('ADDIFYREQUESTAQUOTE_MULTICHECK_OPTIONS', Tools::getValue('aadifyraq_multicheck_options'));
        Configuration::updateValue('ADDIFYREQUESTAQUOTE_DROPDOWN_ACTIVE', Tools::getValue('aadifyraq_dropdown_active'));
        Configuration::updateValue('ADDIFYREQUESTAQUOTE_DROPDOWN_LABLE', Tools::getValue('aadifyraq_dropdown_labe'));
        Configuration::updateValue('ADDIFYREQUESTAQUOTE_DROPDOWN_OPTIONS', Tools::getValue('aadifyraq_dropdown_options'));

        Configuration::updateValue('ADDIFYREQUESTAQUOTE_COMPANYNAME_ACTIVE', Tools::getValue('aadifyraq_companyname_active'));
        Configuration::updateValue('ADDIFYREQUESTAQUOTE_COMPANYNAME_LABLE', Tools::getValue('aadifyraq_companyname_lable'));
        Configuration::updateValue('ADDIFYREQUESTAQUOTE_COMPANYNAME_MANDATORY', Tools::getValue('aadifyraq_companyname_mandatory'));
        Configuration::updateValue('ADDIFYREQUESTAQUOTE_WEBSITE_ACTIVE', Tools::getValue('aadifyraq_website_active'));
        Configuration::updateValue('ADDIFYREQUESTAQUOTE_WEBSITE_LABLE', Tools::getValue('aadifyraq_website_lable'));
        Configuration::updateValue('ADDIFYREQUESTAQUOTE_WEBSITE_MANDATORY', Tools::getValue('aadifyraq_website_mandatory'));
        Configuration::updateValue('ADDIFYREQUESTAQUOTE_PHONE_ACTIVE', Tools::getValue('aadifyraq_phone_active'));
        Configuration::updateValue('ADDIFYREQUESTAQUOTE_PHONE_LABLE', Tools::getValue('aadifyraq_phone_lable'));
        Configuration::updateValue('ADDIFYREQUESTAQUOTE_PHONE_MANDATORY', Tools::getValue('aadifyraq_phone_mandatory'));
        Configuration::updateValue('ADDIFYREQUESTAQUOTE_VATNUMBER_ACTIVE', Tools::getValue('aadifyraq_vatnumber_active'));
        Configuration::updateValue('ADDIFYREQUESTAQUOTE_VATNUMBER_LABLE', Tools::getValue('aadifyraq_vatnumber_lable'));
        Configuration::updateValue('ADDIFYREQUESTAQUOTE_VATNUMBER_MANDATORY', Tools::getValue('aadifyraq_vatnumber_mandatory'));
        Configuration::updateValue('ADDIFYREQUESTAQUOTE_FILEUPLOAD_MANDATORY', Tools::getValue('aadifyraq_fileupload_mandatory'));
        Configuration::updateValue('ADDIFYREQUESTAQUOTE_TEXTTYPE_MANDATORY', Tools::getValue('aadifyraq_texttype_mandatory'));
        Configuration::updateValue('ADDIFYREQUESTAQUOTE_DROPDOWN_MANDATORY', Tools::getValue('aadifyraq_dropdown_mandatory'));
        Configuration::updateValue('ADDIFYREQUESTAQUOTE_MULTISELECT_MANDATORY', Tools::getValue('aadifyraq_multiselect_mandatory'));

        $this->flushCache();

        Tools::redirectAdmin($this->context->link->getAdminLink('AdminModules', true) . '&conf=6&configure=' . $this->name . '&tab_module=' . $this->tab . '&module_name=' . $this->name.'&predefinedaddifyrequestaquote');
    }

    protected function renderFieldsList()
    {

        $fields_list = array(

            'id_addifyrequestaquote' => array(
                'title' => $this->l('Field ID'),
                'width' => 120,
                'type' => 'text',
                'search' => false,
                'orderby' => false
            ),

            'field_active' => array(
                'title' => $this->l('Field Status'),
                'width' => 140,
                'active' => 'status',
                'type' => 'bool',
                'search' => false,
                'orderby' => false
            ),

            'field_type' => array(
                'title' => $this->l('Field Type'),
                'width' => 140,
                'type' => 'text',
                'search' => false,
                'orderby' => false

            ),

            'field_name' => array(
                'title' => $this->l('Field Name'),
                'width' => 140,
                'type' => 'text',
                'search' => false,
                'orderby' => false,
            ),

            'field_label' => array(
                'title' => $this->l('Field Label'),
                'width' => 140,
                'type' => 'text',
                'search' => false,
                'orderby' => false,
            ),

        );

        // multishop feature
        if (Shop::isFeatureActive()) {
            $this->fields_list['id_shop'] = array(
                'title' => $this->l('ID Shop'),
                'align' => 'center',
                'width' => 25,
                'type' => 'int'
            );
        }

        $helper = new HelperList();
        $helper->shopLinkType = '';
        $helper->simple_header = false;
        $helper->identifier = 'id_addifyrequestaquote';
        $helper->toolbar_btn['new'] =  array(
            'href' => AdminController::$currentIndex.'&configure='.$this->name.'&addcustomfields'.$this->name.'&token='.Tools::getAdminTokenLite('AdminModules').'&customfieldsaddifyrequestaquote',
            'desc' => $this->l('Add new')
        );
        $helper->actions = array('edit', 'delete');
        $helper->bulk_actions = array(
            'delete' => array(
                'text' => $this->l('Delete selected'),
                'icon' => 'icon-trash',
                'confirm' => $this->l('Delete selected items?')
            )
        );
        $helper->listTotal = count(AddifyRequestAQuoteCustomFieldsModel::getListContent());
        $helper->show_toolbar = true;
        $helper->title = $this->l('Custom Fields');
        $helper->table = 'addifyrequestaquotecustomfields';
        $helper->token = Tools::getAdminTokenLite('AdminModules');
        $helper->currentIndex = AdminController::$currentIndex.'&configure='.$this->name.'&customfieldsaddifyrequestaquote';
        return $helper->generateList(AddifyRequestAQuoteCustomFieldsModel::getListContent(), $fields_list);
    }

    protected function renderCustomFieldsForm()
    {   
        $fields_types = array(
            array('id' => 'text', 'name' => 'Text'),
            array('id' => 'textarea', 'name' => 'Textarea'),
            array('id' => 'number', 'name' => 'Number'),
            array('id' => 'email', 'name' => 'Email'),
            array('id' => 'select', 'name' => 'Select'),
            array('id' => 'multiselect', 'name' => 'MultiSelect'),
            array('id' => 'checkbox', 'name' => 'Checkbox(s)'),
            array('id' => 'radio', 'name' => 'Radio Button(s)'),
            array('id' => 'date', 'name' => 'Date'),
            array('id' => 'switch', 'name' => 'Switch'),
            array('id' => 'fileupload', 'name' => 'Attachment'),
            array('id' => 'time', 'name' => 'Time'),
            array('id' => 'color', 'name' => 'color'),
        );

        $fields_form = array(
            'form' => array(
                'legend' => array(
                    'title' => $this->l('Add Custom Fields'),
                    'icon' => 'icon-cogs',
                ),
                'input' => array(
                    array(
                        'type' => 'hidden',
                        'name' => 'id_addifyrequestaquote'
                    ),
                    array(
                        'type' => 'switch',
                        'label' => $this->l('Field Enable'),
                        'name' => 'field_active',
                        'is_bool' => true,
                        'desc' => $this->l('Enable/Disable this Field.'),
                        'values' => array(
                            array(
                                'id' => 'active_on',
                                'value' => 1,
                                'label' => $this->l('Enabled')
                            ),
                            array(
                                'id' => 'active_off',
                                'value' => 0,
                                'label' => $this->l('Disabled')
                            )
                        ),
                    ),
                    array(
                        'type'          => 'text',
                        'label'         => $this->l('Field Name'),
                        'name'          => 'field_name',
                        'desc'   => $this->l('This should be unique for example:"name or middle_name" etc.'),
                        'required' => true,
                    ),
                    array(
                        'type' => 'select',
                        'label' => $this->l('Field Type'),
                        'name' => 'field_type',
                        'desc'   => $this->l('Select a type for the custom field.'),
                        'options' => array(
                            'query' =>  $fields_types,
                            'id' => 'id',
                            'name' => 'name'
                        ),
                    ),
                    
                    array(
                        'type'          => 'text',
                        'label'         => $this->l('Label'),
                        'name'          => 'field_label',
                        'lang' => true,
                        'required' => true,
                    ),
                    array(
                        'type'          => 'text',
                        'label'         => $this->l('Place Holder'),
                        'name'          => 'place_holder',
                        'lang' => true,
                    ),
                    array(
                        'type'          => 'text',
                        'label'         => $this->l('Options'),
                        'name'          => 'options',
                        'placeholder'   => 'option_value1->option_label1,option_value2->option_label2,option_value3->option_label3...',
                        'desc' => $this->l('Separate each value and option with -> and all options->values with comma sign.'),
                    ),
                    array(
                        'type' => 'switch',
                        'label' => $this->l('Values Required'),
                        'name' => 'values_req',
                        'is_bool' => true,
                        'desc' => $this->l('Enable to make a Required input field.'),
                        'values' => array(
                            array(
                                'id' => 'active_on',
                                'value' => 1,
                                'label' => $this->l('Enabled')
                            ),
                            array(
                                'id' => 'active_off',
                                'value' => 0,
                                'label' => $this->l('Disabled')
                            )
                        ),
                    ),
                ),
                'submit' => array(
                    'title' => $this->l('Save'),
                ),
                'buttons' => array(
                    'cancel' => array(
                        'title' => $this->l('Cancel'),
                        'class' => 'btn btn-default',
                        'icon' => 'process-icon-cancel',
                        'href' => AdminController::$currentIndex.'&configure='.$this->name.'&token='.Tools::getAdminTokenLite('AdminModules').'&customfieldsaddifyrequestaquote',
                    ),
                )
            ),
        );

        $helper = new HelperForm();
        $helper->show_toolbar = false;
        $helper->show_cancel_button = false;
        $helper->table = 'addifyrequestaquotecustomfields';
        $helper->module = $this;
        $helper->default_form_language = $this->context->language->id;
        $helper->allow_employee_form_lang = Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG', 0);
        $helper->identifier = 'id_addifyrequestaquote';
        $helper->submit_action = 'Submitcustomfields'.$this->name;
        $helper->currentIndex = AdminController::$currentIndex.'&configure='.$this->name.'&customfieldsaddifyrequestaquote';
        $helper->token = Tools::getAdminTokenLite('AdminModules');
        $helper->back_url = $helper->currentIndex.'&token='.$helper->token;
        
        $helper->tpl_vars = array(
            'fields_value' => $this->getCustomFieldsFormValues(), /* Add values for your inputs */
            'languages' => $this->context->controller->getLanguages(),
            'id_language' => $this->context->language->id,
            'context_link' => Context::getContext()->link,
        );

        return $helper->generateForm(array($fields_form));
    }

    protected function getCustomFieldsFormValues()
    {
        $fields_value = array();
        $languages = Language::getLanguages();

        if (Tools::getValue('id_addifyrequestaquote') && (Tools::isSubmit('Submitcustomfields'.$this->name) === false)) {
            $postBlock = new AddifyRequestAQuoteCustomFieldsModel((int)Tools::getValue('id_addifyrequestaquote'));
            $fields_value['id_addifyrequestaquote'] = $postBlock->id_addifyrequestaquote;
            $fields_value['field_active'] = $postBlock->field_active;
            $fields_value['field_name'] =  $postBlock->field_name;
            $fields_value['field_label'] =  $postBlock->field_label;
            $fields_value['place_holder'] =  $postBlock->place_holder;
            $fields_value['options'] =  $postBlock->options;
            $fields_value['values_req'] =  $postBlock->values_req;
            $fields_value['field_type']= $postBlock->field_type;
        }
        else
        {
            $fields_value['id_addifyrequestaquote'] = Tools::getValue('id_addifyrequestaquote');
            $fields_value['field_active']   = Tools::getValue('field_active');
            $fields_value['field_type']= Tools::getValue('field_type');
            $fields_value['field_name'] =  Tools::getValue('field_name');
            $fields_value['options'] =  Tools::getValue('options');
            $fields_value['values_req'] =  Tools::getValue('values_req');

            /* getting multilingual fields*/
            foreach ($languages as $lang) {
                $fields_value['field_label'][(int)$lang['id_lang']] = Tools::getValue('field_label_'.$lang['id_lang']);
                $fields_value['place_holder'][(int)$lang['id_lang']] = Tools::getValue('place_holder_'.$lang['id_lang']);
            }
        }
        
        return $fields_value;
    }

    protected function processCustomFieldsSave()
    {
        $call_back = 'add';
        $form_values = $this->getCustomFieldsFormValues();
        $languages = Language::getLanguages();

        if (!isset($form_values) && !$form_values) {
            return $this->context->controller->errors[] = $this->l('Empty post values.');
        }
        
        if (empty($form_values['field_name'])) {
            $this->context->controller->errors[] = $this->l('Field Name must be required');
        }

        // foreach ($languages as $lang) {
        //     if (empty($fields_values['field_label'][(int)$lang['id_lang']])) {
        //         $this->context->controller->errors[] = $this->l('Field Label must be required');
        //     }
        // }


        $field_type = $form_values['field_type'];

        if ($field_type == 'select' || $field_type == 'checkbox' || $field_type == 'radio' || $field_type == 'multiselect' ) {

            $field_options_str = $form_values['options'];

            $field_option_sep = explode(',', $field_options_str);

            foreach ($field_option_sep as $key) {

                $str_check = strrpos($key,"->");

                if ($str_check == ''){

                    $this->context->controller->errors[] = $this->l('invalid Pattern in Input Options.');

                }

                $options = explode('->', $key);

                if ($options[0] == ''){

                    $this->context->controller->errors[] = $this->l('invalid value in Input Options.');

                } elseif ($options[1] == ''){

                    $this->context->controller->errors[] = $this->l('invalid option in Input Options.');

                } 

            }

        } 
        
        if (count($this->context->controller->errors)) {
            return $this->context->controller->errors;
        }
        $dt = date("Y-m-d h:i:s");
        if (($id_addifyrequestaquote = Tools::getValue('id_addifyrequestaquote'))) {
           
            $call_back = 'update';
    
            $AddifyRequestAQuoteCustomFieldsModel= new AddifyRequestAQuoteCustomFieldsModel((int)$id_addifyrequestaquote);
            $AddifyRequestAQuoteCustomFieldsModel->date_update = $dt;
            
        } else {
            $AddifyRequestAQuoteCustomFieldsModel = new AddifyRequestAQuoteCustomFieldsModel();
            $AddifyRequestAQuoteCustomFieldsModel->date_add = $dt;
        }

        $AddifyRequestAQuoteCustomFieldsModel->field_active = $form_values['field_active'];
        $AddifyRequestAQuoteCustomFieldsModel->field_type = $form_values['field_type'];
        $AddifyRequestAQuoteCustomFieldsModel->field_name = $form_values['field_name'];
        $AddifyRequestAQuoteCustomFieldsModel->field_label = $form_values['field_label'];
        $AddifyRequestAQuoteCustomFieldsModel->place_holder = $form_values['place_holder'];
        $AddifyRequestAQuoteCustomFieldsModel->options = $form_values['options'];
        $AddifyRequestAQuoteCustomFieldsModel->values_req = $form_values['values_req'];
        

        if (!call_user_func(array($AddifyRequestAQuoteCustomFieldsModel, $call_back))) {
            $this->context->controller->errors = sprintf($this->l('Something went wrong while performing operation %s'), $call_back);
        } else {

            $this->flushCache();

            if($call_back=='add')
            {
                Tools::redirectAdmin($this->context->link->getAdminLink('AdminModules', true) . '&conf=3&configure=' . $this->name . '&tab_module=' . $this->tab . '&module_name=' . $this->name.'&customfieldsaddifyrequestaquote');
            }
            else
            {
                Tools::redirectAdmin($this->context->link->getAdminLink('AdminModules', true) . '&conf=4&configure=' . $this->name . '&tab_module=' . $this->tab . '&module_name=' . $this->name.'&customfieldsaddifyrequestaquote');
            }
            
        }
    }

    public function createCart($allpids,$allpattrids,$setallpprice,$pquantities){

        $allpids=explode(',',$allpids);
        $allpattrids=explode(',',$allpattrids);
        $setallpprice=explode(',',$setallpprice);
        $pquantities=explode(',',$pquantities);
       
        $new_cart = new Cart();
        $new_cart->id_currency = 1;
        $new_cart->id_lang = 1;
        $new_cart->save();

        for ($i=0; $i < count($allpids) ; $i++) { 
            $specific_price = new SpecificPrice();
            $specific_price->id_product = $allpids[$i]; // choosen product id-10
            $specific_price->id_product_attribute = $allpattrids[$i]; // optional or set to 0
            $specific_price->id_cart = $new_cart->id;
            $specific_price->from_quantity = $pquantities[$i];
            $specific_price->price = 150;
            $specific_price->reduction_type = 'percentage';
            $specific_price->reduction_tax = 1;
            $specific_price->id_shop =0;
            $specific_price->id_currency = 0;
            $specific_price->id_country = 0;
            $specific_price->id_group = 0;
            $specific_price->id_customer = 0;
            $specific_price->reduction = 0.0;
            $specific_price->from = date("Y-m-d H:i:s");
            $specific_price->to = "2020-10-10 06:06:06"; // or set date x days from now
            $specific_price->add();
            $new_cart->updateQty($pquantities[$i], $allpids[$i], $allpattrids[$i], false);
        }
    }

    public function sendMail($email,$name,$link, $table) {

        Mail::send(
            $this->context->language->id,
            'sendcart',
            Mail::l('Requested Quote Cart Link'),
            array(
                '{dateTime}' => date ('Y-m-d H:i:s'),
                '{emaillink}' => $table
            ),
            $email,
            $name,
            Configuration::get('PS_SHOP_EMAIL'),
            Configuration::get('PS_SHOP_NAME'),
            null,
            null,
            dirname(__file__).'/mails/'
        );
    }

    public function hookDisplayProductPriceBlock($param)
    {

        if (!$this->active || $param['type']!='weight') {
            return;
        }

        $activecheck=Configuration::get('ADDIFYREQUESTAQUOTE_LIVE_MODE');
        if($activecheck == 0) {
            return;
        }

        $product = $param['product'];
        $activemain = Configuration::get('ADDIFYREQUESTAQUOTE_LIVE_MODE');

        $outofstock = Configuration::get('ADDIFYREQUESTAQUOTE_ENABLE_OUTOFSTOCK');

        $CATALOGMODE = Configuration::get('ADDIFYREQUESTAQUOTE_CATALOGMODE_ENABLE');

        if (is_object($product)) {
            $catas = Product::getProductCategoriesFull($product->id);
            $productId = $product->id;
            $id_product_attribute = $product->id_product_attribute;
        } else {
            $catas = Product::getProductCategoriesFull($product['id_product']);
            $productId = $product['id_product'];
            $id_product_attribute = $product['id_product_attribute'];
        }

        // $customerGroupid = array(Group::getCurrent()->id);

        $customerGroupid = (int)Group::getCurrent()->id;
        $id_manufacturer = (int)$product->id_manufacturer;
        $id_supplier = (int)$product->id_supplier;

        $ruleData = AddifyrequestaquoteClass::getRuleByProduct($productId, $catas, $customerGroupid, $id_manufacturer, $id_supplier);

        $availableQuantity = StockAvailable::getQuantityAvailableByProduct((int)$productId, (int)$id_product_attribute);
        $outOfStockCheck = 'yes';

        if ($CATALOGMODE) {

            $text = Configuration::get('ADDIFYREQUESTAQUOTE_MESSAGE');
            $txtcolor = Configuration::get('ADDIFYREQUESTAQUOTE_TEXT_COLOR');
            $textbg = Configuration::get('ADDIFYREQUESTAQUOTE_TEXT_BG_COLOR');
            $hidePrice = Configuration::get('ADDIFYREQUESTAQUOTE_HIDEPRICE');
            $hideCart = Configuration::get('ADDIFYREQUESTAQUOTE_HIDECART');
            $hideQuote = Configuration::get('ADDIFYREQUESTAQUOTE_HIDEQUOTE');

            if ($hidePrice == 0) {
                $priceHideCheck = 'no';
            }
            else {
                $priceHideCheck = 'yes';
            }
            if ($hideCart==0) {
                $hideCartCheck = 'no';
            }
            else {
                $hideCartCheck = 'yes';
            }

            if ($availableQuantity <= 0) {
                if ($outofstock==0) {
                    $outOfStockCheck = 'no';
                }
            }
            
            $hook_type = $param['type']; 
            if ($hook_type == 'price') {
                if (isset($param['product'])) {
                    $this->context->smarty->assign(array(
                    'pattr' => $param['product']['id_product_attribute'],
                    ));
                }
            }
            
            $this->context->smarty->assign(array(
                'ps_version' => _PS_VERSION_,
                'hideCartCheck' => $hideCartCheck,
                'priceHideCheck'=>$priceHideCheck,
                'outOfStockCheck'=>$outOfStockCheck,
                'textbg'=> $textbg,
                'textcolor'=> $txtcolor,
                'text'=> $text,
                'productId'=>$productId,
                'id_product_attribute'=>$id_product_attribute,
                'activemain'=>$CATALOGMODE,
                'hideQuote'=>$hideQuote,
                'catalogMode'=>$CATALOGMODE,
            ));
            if ( $hook_type == 'price') {
                return $this->display(__FILE__, 'views/templates/hook/pattr.tpl').$this->display(__FILE__, 'views/templates/hook/extendhideprice.tpl');
            } else {
            return $this->display(__FILE__, 'views/templates/hook/extendhideprice.tpl');
            }
        }
        elseif ($ruleData) {

            $text = $ruleData['message'];
            $txtcolor = $ruleData['text_color'];
            $textbg = $ruleData['text_bg_color'];
            $hidePrice = $ruleData['hideprice'];
            $hideCart = $ruleData['hidecart'];
            $hideQuote = '';

            if ($hidePrice==0) {
                $priceHideCheck = 'no';
            }
            else{
                $priceHideCheck = 'yes';
            }
            if ($hideCart==0) {
                $hideCartCheck = 'no';
            }
            else{
                $hideCartCheck = 'yes';
            }

            if ($availableQuantity <= 0) {
                if ($outofstock==0) {
                    $outOfStockCheck = 'no';
                }
            }
            
            $hook_type = $param['type']; 
            if ( $hook_type == 'price') {
                if (isset($param['product'])) {
                    $this->context->smarty->assign(array(
                    'pattr' => $param['product']['id_product_attribute'],
                    ));
                }
            }
            
            $this->context->smarty->assign(array(
                'ps_version' => _PS_VERSION_,
                'hideCartCheck' => $hideCartCheck,
                'priceHideCheck'=>$priceHideCheck,
                'outOfStockCheck'=>$outOfStockCheck,
                'textbg'=>$textbg,
                'textcolor'=>$txtcolor,
                'text'=>$text,
                'productId'=>$productId,
                'id_product_attribute'=>$id_product_attribute,
                'activemain'=>$activemain,
                'hideQuote'=>'',
                'catalogMode'=>$CATALOGMODE,
            ));
            if ( $hook_type == 'price') {
                return $this->display(__FILE__, 'views/templates/hook/pattr.tpl').$this->display(__FILE__, 'views/templates/hook/extendhideprice.tpl');
            } else {
            return $this->display(__FILE__, 'views/templates/hook/extendhideprice.tpl');
            }
        } else {

            if ($availableQuantity <= 0) {
                if ($outofstock == 0) {
                    $outOfStockCheck = 'no';
                }
            }

            $this->context->smarty->assign(array(
                'ps_version' => _PS_VERSION_,
                'hideCartCheck' => 'no',
                'priceHideCheck'=> 'no',
                'outOfStockCheck'=>$outOfStockCheck,
                'textbg'=>'',
                'textcolor'=>'',
                'text'=>'',
                'productId'=>$productId,
                'id_product_attribute'=>$id_product_attribute,
                'activemain'=>$activemain,
                'hideQuote'=>'',
                'catalogMode'=>$CATALOGMODE,
            ));
            return $this->display(__FILE__, 'views/templates/hook/extendhideprice.tpl');
        }
    }

    public function hookDisplayTop($params)
    {
        $activecheck = Configuration::get('ADDIFYREQUESTAQUOTE_LIVE_MODE');
        if($activecheck != 1 ) {
            return;
        }
        $baseUrl = $this->context->shop->getBaseURL(true);
        $this->context->smarty->assign(array(
            'baseurl' => $baseUrl,
        ));
        return $this->display(__FILE__, 'views/templates/hook/addtoquoteicon.tpl');
    }

    /**
    * Add the CSS & JavaScript files you want to be loaded in the BO.
    */
    public function hookDisplayBackOfficeHeader()
    {
        $link = new Link;
        $parameters = array("action" => "action_name");
        $addifyraq_ajax_link = $link->getAdminLink('AdminAddifyrequestaquoteCartlink&action=action_name', $parameters);

        Media::addJsDef(array(
            "addifyraq_ajax_link" => $addifyraq_ajax_link
        ));
        if (Tools::getValue('module_name') == $this->name || Tools::getValue('configure') == $this->name) {

            if (true === Tools::version_compare(_PS_VERSION_, '8.0.0', '>=')) {
               $this->context->controller->addJS($this->_path.'views/js/back_ps8.js');
            }else{
                $this->context->controller->addJS($this->_path.'views/js/back.js');
            }

            $this->context->controller->addCSS($this->_path.'views/css/back.css');
        }
    }

    /**
     * Add the CSS & JavaScript files you want to be added on the FO.
     */
    public function hookDisplayHeader()
    {
        $activecheck = Configuration::get('ADDIFYREQUESTAQUOTE_LIVE_MODE');
        if($activecheck != 1 ) {
            return;
        }
        $link = new Link;
        $parameters = array("action" => "action_name");
        $ajax_link = $link->getModuleLink('addifyrequestaquote','ajax', $parameters);

        $context=Context::getContext();
        $id_lang = (int) $context->language->id;
        $getFields = AddifyRequestAQuoteCustomFieldsModel::getFrontaddifyrequestaquotecustomfields(true, $id_lang);

        Media::addJsDef(array(
            "getFields" => $getFields,
            "ajax_raq_link" => $ajax_link
        ));
        $this->context->controller->addJS($this->_path.'/views/js/front.js');
        $this->context->controller->addCSS($this->_path.'/views/css/front.css');

        if(Tools::getValue('quotecart')=='true') {
            if(Tools::getValue('key')) {

                $haveKey = AddifyrequestsallClass::getKey(Tools::getValue('key'));

                if($haveKey){

                $getCartId = AddifycartsallClass::getCartId(Tools::getValue('key'));
                         
                if($getCartId[0]['cart_id']){
                    $this->context->cookie->__set('id_cart', $getCartId[0]['cart_id']);
                    Tools::redirect($this->context->shop->getBaseURL(true).'cart?action=show');
                }

                }
            }
        }
    }

    public function hookDisplayCustomerAccount($params)
    { 
        $activecheck = Configuration::get('ADDIFYREQUESTAQUOTE_LIVE_MODE');
        if($activecheck != 1 ) {
            return;
        }
        $arq_tab_con_link = $this->context->link->getModuleLink($this->name,'quotehistorytab');
        $this->context->smarty->assign(array(
            'arq_tab_con_link' => $arq_tab_con_link,
        ));
        return $this -> display(__FILE__, '/views/templates/front/quote_history_tab.tpl');
    }

    public function hookActionDeleteGDPRCustomer ($customer) {

        if (!empty($customer['id']) && Validate::isEmail($customer['email'])) {
            $sql = "DELETE FROM "._DB_PREFIX_."addifyrequestsall WHERE id_customer = '".pSQL($customer['id'])."'";
            if (Db::getInstance()->execute($sql)) {
                return json_encode(true);
            }
            return json_encode($this->l('Request a Quote Module : Unable to delete customer using email.'));
        }
    }

    public function hookActionExportGDPRData($customer){
        if (!Tools::isEmpty($customer['id']) && Validate::isEmail($customer['email'])) {
            $sql = "SELECT id_product AS `ID Product`,email AS `Email`,offered_price AS `Price Offered`,name AS `Name`,quantity AS `Quantity`,description AS `Description` FROM "._DB_PREFIX_."addifyrequestsall WHERE id_customer = '".pSQL($customer['id'])."'";
            if ($res = Db::getInstance()->ExecuteS($sql)) {



                return json_encode($res);
            } 
            return json_encode($this->l('Request a Quote Module : Unable to export customer using email.'));
        }
    }

    protected function quoteSavedSendEmail($AddifyrequestsallClass)
    {       
        $product_images = explode(',', $AddifyrequestsallClass->product_image);
        if ($product_images) {
            $image_urls = array_map('trim', $product_images); // Using array_map for clarity
            if ($image_urls) {
                $this->context->smarty->assign('image_urls_here', $image_urls);
                $productImagesHtml = $this->context->smarty->fetch(_PS_MODULE_DIR_.'addifyrequestaquote/views/templates/admin/prodImagesHere.tpl');
            }
        }

        $mail_params = array(
            '{customer_name}' => $AddifyrequestsallClass->name,
            '{quote_name}' => $AddifyrequestsallClass->quote_name,
            '{product_name}' => $AddifyrequestsallClass->product_name,
            '{product_info}' => $AddifyrequestsallClass->product_info,
            '{offered_price}' => $AddifyrequestsallClass->offered_price,
            '{original_price}' => $AddifyrequestsallClass->original_price,
            '{quantity}' => $AddifyrequestsallClass->quantity,
            '{description}' => $AddifyrequestsallClass->description,
            '{product_sku}' => $AddifyrequestsallClass->product_sku,
            '{product_image}' => $productImagesHtml,
            '{status}' => $AddifyrequestsallClass->status,
            '{customer_address_field}' => $AddifyrequestsallClass->customer_address_field,
            '{shipping_address}' => $AddifyrequestsallClass->shipping_field,
            '{quote_product_discount}' => $AddifyrequestsallClass->quote_product_discount,
        );

        $shop_email = Configuration::get('PS_SHOP_EMAIL'); // From email
        $shop_name = Configuration::get('PS_SHOP_NAME'); // From name

        $result = Mail::send(
            $this->context->language->id,
            "sendquote", // Email template name
            Mail::l('Admin quote'),// Email subject
            $mail_params, // Parameters for the email template
            $AddifyrequestsallClass->email, // Recipient email
            $AddifyrequestsallClass->name, // Recipient name
            $shop_email,
            $shop_name,
            null,
            null,
            dirname(__file__).'/mails/' // Corrected template directory
        );
    }


    public function sendMailMessage($email,$name,$message, $id_quotation) {

        $adminemail = Configuration::get('PS_SHOP_EMAIL');
        
        Mail::send(
            $this->context->language->id,
            'sendmessagecustomer',
            Mail::l('Store Admin Send a Message'),
            array(
                '{dateTime}' => date ('Y-m-d H:i:s'),
                '{message}' => $message,
                '{email}' => $adminemail,
                '{name}' => $name,
                '{id_quotation}' => $id_quotation,
                '{shop_name}' => Configuration::get('PS_SHOP_NAME'),
                
            ),
            $email,
            $name,
            Configuration::get('PS_SHOP_EMAIL'),
            Configuration::get('PS_SHOP_NAME'),
            null,
            null,
            dirname(__file__).'/mails/'
        );
    }

}
